/* contacts-store.c generated by valac 0.32.0.15-114e9, the Vala compiler
 * generated from contacts-store.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 8 -*- */
/*
 * Copyright (C) 2011 Alexander Larsson <alexl@redhat.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <glib.h>
#include <glib-object.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <telepathy-glib/telepathy-glib.h>
#include <folks/folks.h>
#include <glib/gstdio.h>
#include <gio/gio.h>


#define CONTACTS_TYPE_STORE (contacts_store_get_type ())
#define CONTACTS_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_STORE, ContactsStore))
#define CONTACTS_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_STORE, ContactsStoreClass))
#define CONTACTS_IS_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_STORE))
#define CONTACTS_IS_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_STORE))
#define CONTACTS_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_STORE, ContactsStoreClass))

typedef struct _ContactsStore ContactsStore;
typedef struct _ContactsStoreClass ContactsStoreClass;
typedef struct _ContactsStorePrivate ContactsStorePrivate;

#define CONTACTS_TYPE_CONTACT (contacts_contact_get_type ())
#define CONTACTS_CONTACT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONTACTS_TYPE_CONTACT, ContactsContact))
#define CONTACTS_CONTACT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONTACTS_TYPE_CONTACT, ContactsContactClass))
#define CONTACTS_IS_CONTACT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONTACTS_TYPE_CONTACT))
#define CONTACTS_IS_CONTACT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONTACTS_TYPE_CONTACT))
#define CONTACTS_CONTACT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONTACTS_TYPE_CONTACT, ContactsContactClass))

typedef struct _ContactsContact ContactsContact;
typedef struct _ContactsContactClass ContactsContactClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))
typedef struct _ContactsContactPrivate ContactsContactPrivate;
typedef struct _Block35Data Block35Data;
typedef struct _ContactsStoreFindContactData ContactsStoreFindContactData;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))
typedef struct _ContactsStoreCheckCallCapabilitiesData ContactsStoreCheckCallCapabilitiesData;
typedef struct _ContactsStoreCheckAccountCapsData ContactsStoreCheckAccountCapsData;

struct _ContactsStore {
	GObject parent_instance;
	ContactsStorePrivate * priv;
	GeeHashMap* calling_accounts;
	GeeHashMultiMap* dont_suggest_link;
};

struct _ContactsStoreClass {
	GObjectClass parent_class;
};

struct _ContactsStorePrivate {
	FolksIndividualAggregator* _aggregator;
	FolksBackendStore* _backend_store;
	GeeArrayList* contacts;
};

struct _ContactsContact {
	GObject parent_instance;
	ContactsContactPrivate * priv;
	ContactsStore* store;
	gboolean is_main;
	FolksPresenceType presence_type;
	gchar* presence_message;
	gboolean is_phone;
	FolksIndividual* individual;
	FolksPersona* fake_persona;
};

struct _ContactsContactClass {
	GObjectClass parent_class;
};

typedef gboolean (*ContactsStoreContactMatcher) (ContactsContact* c, void* user_data);
struct _Block35Data {
	int _ref_count_;
	ContactsStore* self;
	ContactsContact* matched;
	GSourceFunc callback;
	gpointer callback_target;
	GDestroyNotify callback_target_destroy_notify;
	ContactsStoreContactMatcher matcher;
	gpointer matcher_target;
	gpointer _async_data_;
};

struct _ContactsStoreFindContactData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	ContactsStore* self;
	ContactsStoreContactMatcher matcher;
	gpointer matcher_target;
	ContactsContact* result;
	Block35Data* _data35_;
	ContactsStoreContactMatcher _tmp0_;
	void* _tmp0__target;
	GeeArrayList* _c_list;
	GeeArrayList* _tmp1_;
	GeeArrayList* _tmp2_;
	gint _c_size;
	GeeArrayList* _tmp3_;
	gint _tmp4_;
	gint _tmp5_;
	gint _c_index;
	gint _tmp6_;
	gint _tmp7_;
	gint _tmp8_;
	ContactsContact* c;
	GeeArrayList* _tmp9_;
	gint _tmp10_;
	gpointer _tmp11_;
	ContactsStoreContactMatcher _tmp12_;
	void* _tmp12__target;
	ContactsContact* _tmp13_;
	gboolean _tmp14_;
	gboolean _tmp15_;
	gboolean _tmp16_;
	gulong id1;
	gulong id2;
	gulong id3;
	gulong _tmp17_;
	gulong _tmp18_;
	gulong _tmp19_;
	gulong _tmp20_;
	gulong _tmp21_;
	gulong _tmp22_;
	ContactsContact* _tmp23_;
	ContactsContact* _tmp24_;
};

struct _ContactsStoreCheckCallCapabilitiesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	ContactsStore* self;
	GeeHashMap* _tmp0_;
	TpAccountManager* account_manager;
	TpAccountManager* _tmp1_;
	GList* _tmp2_;
	GList* account_collection;
	GList* account_it;
	TpAccount* account;
	TpAccount* _tmp3_;
	GError* e;
	GError* _tmp4_;
	const gchar* _tmp5_;
	GError * _inner_error_;
};

struct _ContactsStoreCheckAccountCapsData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	ContactsStore* self;
	TpAccount* account;
	GQuark addressing;
	GQuark _tmp0_;
	TpAccount* _tmp1_;
	GQuark _tmp2_;
	gboolean _tmp3_;
	GQuark* features;
	GQuark _tmp4_;
	GQuark* _tmp5_;
	gint features_length1;
	gint _features_size_;
	TpAccount* _tmp6_;
	GQuark* _tmp7_;
	gint _tmp7__length1;
	GError* e;
	GError* _tmp8_;
	const gchar* _tmp9_;
	TpAccount* _tmp10_;
	GQuark _tmp11_;
	gboolean _tmp12_;
	gchar* k;
	TpAccount* _tmp13_;
	const gchar* _tmp14_;
	gchar* _tmp15_;
	gboolean _tmp16_;
	TpAccount* _tmp17_;
	gboolean _tmp18_;
	TpAccount* _tmp19_;
	gboolean _tmp20_;
	GeeHashMap* _tmp21_;
	const gchar* _tmp22_;
	TpAccount* _tmp23_;
	GeeHashMap* _tmp24_;
	const gchar* _tmp25_;
	GError * _inner_error_;
};


static gpointer contacts_store_parent_class = NULL;

GType contacts_store_get_type (void) G_GNUC_CONST;
GType contacts_contact_get_type (void) G_GNUC_CONST;
#define CONTACTS_STORE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CONTACTS_TYPE_STORE, ContactsStorePrivate))
enum  {
	CONTACTS_STORE_DUMMY_PROPERTY,
	CONTACTS_STORE_AGGREGATOR,
	CONTACTS_STORE_BACKEND_STORE,
	CONTACTS_STORE_CAN_CALL,
	CONTACTS_STORE_IS_QUIESCENT,
	CONTACTS_STORE_IS_PREPARED
};
void contacts_store_refresh (ContactsStore* self);
void contacts_contact_queue_changed (ContactsContact* self, gboolean is_persona_change);
static gboolean contacts_store_individual_can_replace_at_split (ContactsStore* self, FolksIndividual* new_individual);
static gboolean contacts_store_individual_should_replace_at_join (ContactsStore* self, FolksIndividual* old_individual);
ContactsContact* contacts_contact_from_individual (FolksIndividual* i);
static void contacts_store_read_dont_suggest_db (ContactsStore* self);
static void contacts_store_write_dont_suggest_db (ContactsStore* self);
gboolean contacts_store_may_suggest_link (ContactsStore* self, ContactsContact* a, ContactsContact* b);
void contacts_store_add_no_suggest_link (ContactsStore* self, ContactsContact* a, ContactsContact* b);
GeeList* contacts_contact_get_personas_for_display (ContactsContact* self);
static void contacts_store_contact_changed_cb (ContactsStore* self, ContactsContact* c);
static void contacts_store_find_contact_data_free (gpointer _data);
void contacts_store_find_contact (ContactsStore* self, ContactsStoreContactMatcher matcher, void* matcher_target, GAsyncReadyCallback _callback_, gpointer _user_data_);
ContactsContact* contacts_store_find_contact_finish (ContactsStore* self, GAsyncResult* _res_);
static gboolean contacts_store_find_contact_co (ContactsStoreFindContactData* _data_);
static Block35Data* block35_data_ref (Block35Data* _data35_);
static void block35_data_unref (void * _userdata_);
gboolean contacts_store_get_is_quiescent (ContactsStore* self);
static gboolean _contacts_store_find_contact_co_gsource_func (gpointer self);
static void __lambda17_ (Block35Data* _data35_, ContactsContact* c);
static void ___lambda17__contacts_store_changed (ContactsStore* _sender, ContactsContact* c, gpointer self);
static void __lambda18_ (Block35Data* _data35_, ContactsContact* c);
static void ___lambda18__contacts_store_added (ContactsStore* _sender, ContactsContact* c, gpointer self);
static void __lambda19_ (Block35Data* _data35_);
static void ___lambda19__contacts_store_quiescent (ContactsStore* _sender, gpointer self);
ContactsContact* contacts_store_find_contact_with_persona (ContactsStore* self, FolksPersona* persona);
GeeCollection* contacts_store_get_contacts (ContactsStore* self);
gboolean contacts_store_is_empty (ContactsStore* self);
gboolean contacts_contact_get_is_hidden (ContactsContact* self);
static void contacts_store_add (ContactsStore* self, ContactsContact* c);
static void _contacts_store_contact_changed_cb_contacts_contact_changed (ContactsContact* _sender, gpointer self);
static void contacts_store_remove (ContactsStore* self, ContactsContact* c);
static void contacts_store_check_call_capabilities_data_free (gpointer _data);
static void contacts_store_check_call_capabilities (ContactsStore* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void contacts_store_check_call_capabilities_finish (ContactsStore* self, GAsyncResult* _res_);
static gboolean contacts_store_check_call_capabilities_co (ContactsStoreCheckCallCapabilitiesData* _data_);
static void contacts_store_check_call_capabilities_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void contacts_store_check_account_caps (ContactsStore* self, TpAccount* account, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void contacts_store_check_account_caps_finish (ContactsStore* self, GAsyncResult* _res_);
static void _contacts_store_check_account_caps_tp_account_manager_account_enabled (TpAccountManager* _sender, TpAccount* account, gpointer self);
static void _contacts_store_check_account_caps_tp_account_manager_account_disabled (TpAccountManager* _sender, TpAccount* account, gpointer self);
static void contacts_store_check_account_caps_data_free (gpointer _data);
static gboolean contacts_store_check_account_caps_co (ContactsStoreCheckAccountCapsData* _data_);
static void contacts_store_check_account_caps_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
ContactsStore* contacts_store_new (void);
ContactsStore* contacts_store_construct (GType object_type);
FolksIndividualAggregator* contacts_store_get_aggregator (ContactsStore* self);
static void contacts_store_set_aggregator (ContactsStore* self, FolksIndividualAggregator* value);
FolksBackendStore* contacts_store_get_backend_store (ContactsStore* self);
static void contacts_store_set_backend_store (ContactsStore* self, FolksBackendStore* value);
gboolean contacts_store_get_can_call (ContactsStore* self);
gboolean contacts_store_get_is_prepared (ContactsStore* self);
static GObject * contacts_store_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _contacts_store___lambda20_ (ContactsStore* self, FolksBackend* backend);
static void ___lambda21_ (ContactsStore* self);
static void ____lambda21__folks_backend_persona_store_added (FolksBackend* _sender, FolksPersonaStore* store, gpointer self);
static void ___lambda22_ (ContactsStore* self);
static void ____lambda22__folks_backend_persona_store_removed (FolksBackend* _sender, FolksPersonaStore* store, gpointer self);
static void __contacts_store___lambda20__folks_backend_store_backend_available (FolksBackendStore* _sender, FolksBackend* backend, gpointer self);
static void _contacts_store___lambda23_ (ContactsStore* self, GObject* obj, GParamSpec* pspec);
static gboolean __lambda24_ (ContactsStore* self);
static gboolean ___lambda24__gsource_func (gpointer self);
static void __contacts_store___lambda23__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _contacts_store___lambda25_ (ContactsStore* self, GObject* obj, GParamSpec* pspec);
static gboolean __lambda26_ (ContactsStore* self);
static gboolean ___lambda26__gsource_func (gpointer self);
static void __contacts_store___lambda25__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void _contacts_store___lambda27_ (ContactsStore* self, GeeMultiMap* changes);
ContactsContact* contacts_contact_new (ContactsStore* store, FolksIndividual* i);
ContactsContact* contacts_contact_construct (GType object_type, ContactsStore* store, FolksIndividual* i);
void contacts_contact_replace_individual (ContactsContact* self, FolksIndividual* new_individual);
static void __contacts_store___lambda27__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void contacts_store_finalize (GObject* obj);
static void _vala_contacts_store_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_contacts_store_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


static gpointer _g_object_ref0 (gpointer self) {
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return self ? g_object_ref (self) : NULL;
#line 317 "contacts-store.c"
}


void contacts_store_refresh (ContactsStore* self) {
#line 55 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (self != NULL);
#line 324 "contacts-store.c"
	{
		GeeArrayList* _c_list = NULL;
		GeeArrayList* _tmp0_ = NULL;
		GeeArrayList* _tmp1_ = NULL;
		gint _c_size = 0;
		GeeArrayList* _tmp2_ = NULL;
		gint _tmp3_ = 0;
		gint _tmp4_ = 0;
		gint _c_index = 0;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp0_ = self->priv->contacts;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_c_list = _tmp1_;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp2_ = _c_list;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp3_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp2_);
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp4_ = _tmp3_;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_c_size = _tmp4_;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_c_index = -1;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		while (TRUE) {
#line 352 "contacts-store.c"
			gint _tmp5_ = 0;
			gint _tmp6_ = 0;
			gint _tmp7_ = 0;
			ContactsContact* c = NULL;
			GeeArrayList* _tmp8_ = NULL;
			gint _tmp9_ = 0;
			gpointer _tmp10_ = NULL;
			ContactsContact* _tmp11_ = NULL;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp5_ = _c_index;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_c_index = _tmp5_ + 1;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp6_ = _c_index;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp7_ = _c_size;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			if (!(_tmp6_ < _tmp7_)) {
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				break;
#line 373 "contacts-store.c"
			}
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp8_ = _c_list;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp9_ = _c_index;
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp10_ = gee_abstract_list_get ((GeeAbstractList*) _tmp8_, _tmp9_);
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			c = (ContactsContact*) _tmp10_;
#line 57 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp11_ = c;
#line 57 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			contacts_contact_queue_changed (_tmp11_, TRUE);
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_g_object_unref0 (c);
#line 389 "contacts-store.c"
		}
#line 56 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_object_unref0 (_c_list);
#line 393 "contacts-store.c"
	}
}


static gboolean contacts_store_individual_can_replace_at_split (ContactsStore* self, FolksIndividual* new_individual) {
	gboolean result = FALSE;
#line 61 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 61 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_val_if_fail (new_individual != NULL, FALSE);
#line 404 "contacts-store.c"
	{
		GeeIterator* _p_it = NULL;
		FolksIndividual* _tmp0_ = NULL;
		GeeSet* _tmp1_ = NULL;
		GeeSet* _tmp2_ = NULL;
		GeeIterator* _tmp3_ = NULL;
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp0_ = new_individual;
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp1_ = folks_individual_get_personas (_tmp0_);
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp2_ = _tmp1_;
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp3_ = gee_iterable_iterator ((GeeIterable*) _tmp2_);
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_p_it = _tmp3_;
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		while (TRUE) {
#line 423 "contacts-store.c"
			GeeIterator* _tmp4_ = NULL;
			gboolean _tmp5_ = FALSE;
			FolksPersona* p = NULL;
			GeeIterator* _tmp6_ = NULL;
			gpointer _tmp7_ = NULL;
			FolksPersona* _tmp8_ = NULL;
			gconstpointer _tmp9_ = NULL;
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp4_ = _p_it;
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp5_ = gee_iterator_next (_tmp4_);
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			if (!_tmp5_) {
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				break;
#line 439 "contacts-store.c"
			}
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp6_ = _p_it;
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp7_ = gee_iterator_get (_tmp6_);
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			p = (FolksPersona*) _tmp7_;
#line 63 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp8_ = p;
#line 63 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp9_ = g_object_get_data ((GObject*) _tmp8_, "contacts-new-contact");
#line 63 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			if ((gboolean) ((gintptr) _tmp9_)) {
#line 64 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				result = FALSE;
#line 64 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_g_object_unref0 (p);
#line 64 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_g_object_unref0 (_p_it);
#line 64 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				return result;
#line 461 "contacts-store.c"
			}
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_g_object_unref0 (p);
#line 465 "contacts-store.c"
		}
#line 62 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_object_unref0 (_p_it);
#line 469 "contacts-store.c"
	}
#line 66 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	result = TRUE;
#line 66 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return result;
#line 475 "contacts-store.c"
}


static gboolean contacts_store_individual_should_replace_at_join (ContactsStore* self, FolksIndividual* old_individual) {
	gboolean result = FALSE;
	ContactsContact* c = NULL;
	FolksIndividual* _tmp0_ = NULL;
	ContactsContact* _tmp1_ = NULL;
	gconstpointer _tmp2_ = NULL;
#line 69 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 69 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_val_if_fail (old_individual != NULL, FALSE);
#line 70 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = old_individual;
#line 70 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp1_ = contacts_contact_from_individual (_tmp0_);
#line 70 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	c = _tmp1_;
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp2_ = g_object_get_data ((GObject*) c, "contacts-master-at-join");
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	result = (gboolean) ((gintptr) _tmp2_);
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (c);
#line 71 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return result;
#line 503 "contacts-store.c"
}


static void contacts_store_read_dont_suggest_db (ContactsStore* self) {
	GeeHashMultiMap* _tmp0_ = NULL;
	GError * _inner_error_ = NULL;
#line 74 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (self != NULL);
#line 75 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = self->dont_suggest_link;
#line 75 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	gee_multi_map_clear ((GeeMultiMap*) _tmp0_);
#line 516 "contacts-store.c"
	{
		gchar* path = NULL;
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* contents = NULL;
		gboolean _tmp3_ = FALSE;
		gchar* _tmp4_ = NULL;
		gboolean _tmp5_ = FALSE;
#line 77 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp1_ = g_get_user_config_dir ();
#line 77 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp2_ = g_build_filename (_tmp1_, "gnome-contacts", "dont_suggest.db", NULL);
#line 77 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		path = _tmp2_;
#line 79 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp5_ = g_file_get_contents (path, &_tmp4_, NULL, &_inner_error_);
#line 79 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_free0 (contents);
#line 79 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		contents = _tmp4_;
#line 79 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp3_ = _tmp5_;
#line 79 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 79 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_g_free0 (contents);
#line 79 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_g_free0 (path);
#line 545 "contacts-store.c"
			goto __catch24_g_error;
		}
#line 79 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		if (_tmp3_) {
#line 550 "contacts-store.c"
			gchar** rows = NULL;
			gchar** _tmp6_ = NULL;
			gchar** _tmp7_ = NULL;
			gint rows_length1 = 0;
			gint _rows_size_ = 0;
			gchar** _tmp8_ = NULL;
			gint _tmp8__length1 = 0;
#line 80 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp7_ = _tmp6_ = g_strsplit (contents, "\n", 0);
#line 80 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			rows = _tmp7_;
#line 80 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			rows_length1 = _vala_array_length (_tmp6_);
#line 80 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_rows_size_ = rows_length1;
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp8_ = rows;
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp8__length1 = rows_length1;
#line 570 "contacts-store.c"
			{
				gchar** r_collection = NULL;
				gint r_collection_length1 = 0;
				gint _r_collection_size_ = 0;
				gint r_it = 0;
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				r_collection = _tmp8_;
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				r_collection_length1 = _tmp8__length1;
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				for (r_it = 0; r_it < _tmp8__length1; r_it = r_it + 1) {
#line 582 "contacts-store.c"
					gchar* _tmp9_ = NULL;
					gchar* r = NULL;
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp9_ = g_strdup (r_collection[r_it]);
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					r = _tmp9_;
#line 589 "contacts-store.c"
					{
						gchar** ids = NULL;
						const gchar* _tmp10_ = NULL;
						gchar** _tmp11_ = NULL;
						gchar** _tmp12_ = NULL;
						gint ids_length1 = 0;
						gint _ids_size_ = 0;
						gchar** _tmp13_ = NULL;
						gint _tmp13__length1 = 0;
#line 82 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp10_ = r;
#line 82 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp12_ = _tmp11_ = g_strsplit (_tmp10_, " ", 0);
#line 82 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						ids = _tmp12_;
#line 82 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						ids_length1 = _vala_array_length (_tmp11_);
#line 82 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_ids_size_ = ids_length1;
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp13_ = ids;
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp13__length1 = ids_length1;
#line 83 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						if (_tmp13__length1 == 2) {
#line 615 "contacts-store.c"
							GeeHashMultiMap* _tmp14_ = NULL;
							gchar** _tmp15_ = NULL;
							gint _tmp15__length1 = 0;
							const gchar* _tmp16_ = NULL;
							gchar** _tmp17_ = NULL;
							gint _tmp17__length1 = 0;
							const gchar* _tmp18_ = NULL;
#line 84 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp14_ = self->dont_suggest_link;
#line 84 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp15_ = ids;
#line 84 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp15__length1 = ids_length1;
#line 84 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp16_ = _tmp15_[0];
#line 84 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp17_ = ids;
#line 84 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp17__length1 = ids_length1;
#line 84 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp18_ = _tmp17_[1];
#line 84 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							gee_multi_map_set ((GeeMultiMap*) _tmp14_, _tmp16_, _tmp18_);
#line 639 "contacts-store.c"
						}
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						ids = (_vala_array_free (ids, ids_length1, (GDestroyNotify) g_free), NULL);
#line 81 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_g_free0 (r);
#line 645 "contacts-store.c"
					}
				}
			}
#line 79 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			rows = (_vala_array_free (rows, rows_length1, (GDestroyNotify) g_free), NULL);
#line 651 "contacts-store.c"
		}
#line 76 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_free0 (contents);
#line 76 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_free0 (path);
#line 657 "contacts-store.c"
	}
	goto __finally24;
	__catch24_g_error:
	{
		GError* e = NULL;
		GError* _tmp19_ = NULL;
#line 76 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		e = _inner_error_;
#line 76 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_inner_error_ = NULL;
#line 89 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp19_ = e;
#line 89 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		if (!g_error_matches (_tmp19_, G_FILE_ERROR, G_FILE_ERROR_NOENT)) {
#line 672 "contacts-store.c"
			GError* _tmp20_ = NULL;
			const gchar* _tmp21_ = NULL;
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp20_ = e;
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp21_ = _tmp20_->message;
#line 90 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			g_warning ("contacts-store.vala:90: error loading no suggestion db: %s\n", _tmp21_);
#line 681 "contacts-store.c"
		}
#line 76 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_error_free0 (e);
#line 685 "contacts-store.c"
	}
	__finally24:
#line 76 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 76 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 76 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_clear_error (&_inner_error_);
#line 76 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		return;
#line 696 "contacts-store.c"
	}
}


static void contacts_store_write_dont_suggest_db (ContactsStore* self) {
	GError * _inner_error_ = NULL;
#line 94 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (self != NULL);
#line 705 "contacts-store.c"
	{
		gchar* dir = NULL;
		const gchar* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
		gchar* path = NULL;
		const gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		GString* s = NULL;
		GString* _tmp5_ = NULL;
		const gchar* _tmp28_ = NULL;
		GString* _tmp29_ = NULL;
		const gchar* _tmp30_ = NULL;
		GString* _tmp31_ = NULL;
		gssize _tmp32_ = 0L;
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp0_ = g_get_user_config_dir ();
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp1_ = g_build_filename (_tmp0_, "gnome-contacts", NULL);
#line 96 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		dir = _tmp1_;
#line 97 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp2_ = dir;
#line 97 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_mkdir_with_parents (_tmp2_, 0700);
#line 98 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp3_ = dir;
#line 98 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp4_ = g_build_filename (_tmp3_, "dont_suggest.db", NULL);
#line 98 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		path = _tmp4_;
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp5_ = g_string_new ("");
#line 100 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		s = _tmp5_;
#line 741 "contacts-store.c"
		{
			GeeIterator* _key_it = NULL;
			GeeHashMultiMap* _tmp6_ = NULL;
			GeeSet* _tmp7_ = NULL;
			GeeSet* _tmp8_ = NULL;
			GeeIterator* _tmp9_ = NULL;
			GeeIterator* _tmp10_ = NULL;
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp6_ = self->dont_suggest_link;
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp7_ = gee_multi_map_get_keys ((GeeMultiMap*) _tmp6_);
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp8_ = _tmp7_;
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp9_ = gee_iterable_iterator ((GeeIterable*) _tmp8_);
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp10_ = _tmp9_;
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_g_object_unref0 (_tmp8_);
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_key_it = _tmp10_;
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			while (TRUE) {
#line 765 "contacts-store.c"
				GeeIterator* _tmp11_ = NULL;
				gboolean _tmp12_ = FALSE;
				gchar* key = NULL;
				GeeIterator* _tmp13_ = NULL;
				gpointer _tmp14_ = NULL;
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp11_ = _key_it;
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp12_ = gee_iterator_next (_tmp11_);
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				if (!_tmp12_) {
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					break;
#line 779 "contacts-store.c"
				}
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp13_ = _key_it;
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp14_ = gee_iterator_get (_tmp13_);
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				key = (gchar*) _tmp14_;
#line 787 "contacts-store.c"
				{
					GeeIterator* _value_it = NULL;
					GeeHashMultiMap* _tmp15_ = NULL;
					const gchar* _tmp16_ = NULL;
					GeeCollection* _tmp17_ = NULL;
					GeeCollection* _tmp18_ = NULL;
					GeeIterator* _tmp19_ = NULL;
					GeeIterator* _tmp20_ = NULL;
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp15_ = self->dont_suggest_link;
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp16_ = key;
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp17_ = gee_multi_map_get ((GeeMultiMap*) _tmp15_, _tmp16_);
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp18_ = _tmp17_;
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp19_ = gee_iterable_iterator ((GeeIterable*) _tmp18_);
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp20_ = _tmp19_;
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_g_object_unref0 (_tmp18_);
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_value_it = _tmp20_;
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					while (TRUE) {
#line 814 "contacts-store.c"
						GeeIterator* _tmp21_ = NULL;
						gboolean _tmp22_ = FALSE;
						gchar* value = NULL;
						GeeIterator* _tmp23_ = NULL;
						gpointer _tmp24_ = NULL;
						GString* _tmp25_ = NULL;
						const gchar* _tmp26_ = NULL;
						const gchar* _tmp27_ = NULL;
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp21_ = _value_it;
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp22_ = gee_iterator_next (_tmp21_);
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						if (!_tmp22_) {
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							break;
#line 831 "contacts-store.c"
						}
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp23_ = _value_it;
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp24_ = gee_iterator_get (_tmp23_);
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						value = (gchar*) _tmp24_;
#line 103 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp25_ = s;
#line 103 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp26_ = key;
#line 103 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp27_ = value;
#line 103 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						g_string_append_printf (_tmp25_, "%s %s\n", _tmp26_, _tmp27_);
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_g_free0 (value);
#line 849 "contacts-store.c"
					}
#line 102 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_g_object_unref0 (_value_it);
#line 853 "contacts-store.c"
				}
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_g_free0 (key);
#line 857 "contacts-store.c"
			}
#line 101 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_g_object_unref0 (_key_it);
#line 861 "contacts-store.c"
		}
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp28_ = path;
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp29_ = s;
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp30_ = _tmp29_->str;
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp31_ = s;
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp32_ = _tmp31_->len;
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_file_set_contents (_tmp28_, _tmp30_, _tmp32_, &_inner_error_);
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_g_string_free0 (s);
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_g_free0 (path);
#line 106 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_g_free0 (dir);
#line 883 "contacts-store.c"
			goto __catch25_g_error;
		}
#line 95 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_string_free0 (s);
#line 95 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_free0 (path);
#line 95 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_free0 (dir);
#line 892 "contacts-store.c"
	}
	goto __finally25;
	__catch25_g_error:
	{
		GError* e = NULL;
		GError* _tmp33_ = NULL;
		const gchar* _tmp34_ = NULL;
#line 95 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		e = _inner_error_;
#line 95 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_inner_error_ = NULL;
#line 108 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp33_ = e;
#line 108 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp34_ = _tmp33_->message;
#line 108 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_warning ("contacts-store.vala:108: error writing no suggestion db: %s\n", _tmp34_);
#line 95 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_error_free0 (e);
#line 912 "contacts-store.c"
	}
	__finally25:
#line 95 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 95 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 95 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_clear_error (&_inner_error_);
#line 95 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		return;
#line 923 "contacts-store.c"
	}
}


gboolean contacts_store_may_suggest_link (ContactsStore* self, ContactsContact* a, ContactsContact* b) {
	gboolean result = FALSE;
#line 112 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 112 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_val_if_fail (a != NULL, FALSE);
#line 112 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_val_if_fail (b != NULL, FALSE);
#line 936 "contacts-store.c"
	{
		GeeIterator* _a_persona_it = NULL;
		ContactsContact* _tmp0_ = NULL;
		FolksIndividual* _tmp1_ = NULL;
		GeeSet* _tmp2_ = NULL;
		GeeSet* _tmp3_ = NULL;
		GeeIterator* _tmp4_ = NULL;
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp0_ = a;
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp1_ = _tmp0_->individual;
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp2_ = folks_individual_get_personas (_tmp1_);
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp3_ = _tmp2_;
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp4_ = gee_iterable_iterator ((GeeIterable*) _tmp3_);
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_a_persona_it = _tmp4_;
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		while (TRUE) {
#line 958 "contacts-store.c"
			GeeIterator* _tmp5_ = NULL;
			gboolean _tmp6_ = FALSE;
			FolksPersona* a_persona = NULL;
			GeeIterator* _tmp7_ = NULL;
			gpointer _tmp8_ = NULL;
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp5_ = _a_persona_it;
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp6_ = gee_iterator_next (_tmp5_);
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			if (!_tmp6_) {
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				break;
#line 972 "contacts-store.c"
			}
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp7_ = _a_persona_it;
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp8_ = gee_iterator_get (_tmp7_);
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			a_persona = (FolksPersona*) _tmp8_;
#line 980 "contacts-store.c"
			{
				GeeIterator* _no_link_uid_it = NULL;
				GeeHashMultiMap* _tmp9_ = NULL;
				FolksPersona* _tmp10_ = NULL;
				const gchar* _tmp11_ = NULL;
				const gchar* _tmp12_ = NULL;
				GeeCollection* _tmp13_ = NULL;
				GeeCollection* _tmp14_ = NULL;
				GeeIterator* _tmp15_ = NULL;
				GeeIterator* _tmp16_ = NULL;
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp9_ = self->dont_suggest_link;
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp10_ = a_persona;
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp11_ = folks_persona_get_uid (_tmp10_);
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp12_ = _tmp11_;
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp13_ = gee_multi_map_get ((GeeMultiMap*) _tmp9_, _tmp12_);
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp14_ = _tmp13_;
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp15_ = gee_iterable_iterator ((GeeIterable*) _tmp14_);
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp16_ = _tmp15_;
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_g_object_unref0 (_tmp14_);
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_no_link_uid_it = _tmp16_;
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				while (TRUE) {
#line 1013 "contacts-store.c"
					GeeIterator* _tmp17_ = NULL;
					gboolean _tmp18_ = FALSE;
					gchar* no_link_uid = NULL;
					GeeIterator* _tmp19_ = NULL;
					gpointer _tmp20_ = NULL;
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp17_ = _no_link_uid_it;
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp18_ = gee_iterator_next (_tmp17_);
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					if (!_tmp18_) {
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						break;
#line 1027 "contacts-store.c"
					}
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp19_ = _no_link_uid_it;
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp20_ = gee_iterator_get (_tmp19_);
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					no_link_uid = (gchar*) _tmp20_;
#line 1035 "contacts-store.c"
					{
						GeeIterator* _b_persona_it = NULL;
						ContactsContact* _tmp21_ = NULL;
						FolksIndividual* _tmp22_ = NULL;
						GeeSet* _tmp23_ = NULL;
						GeeSet* _tmp24_ = NULL;
						GeeIterator* _tmp25_ = NULL;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp21_ = b;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp22_ = _tmp21_->individual;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp23_ = folks_individual_get_personas (_tmp22_);
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp24_ = _tmp23_;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp25_ = gee_iterable_iterator ((GeeIterable*) _tmp24_);
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_b_persona_it = _tmp25_;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						while (TRUE) {
#line 1057 "contacts-store.c"
							GeeIterator* _tmp26_ = NULL;
							gboolean _tmp27_ = FALSE;
							FolksPersona* b_persona = NULL;
							GeeIterator* _tmp28_ = NULL;
							gpointer _tmp29_ = NULL;
							FolksPersona* _tmp30_ = NULL;
							const gchar* _tmp31_ = NULL;
							const gchar* _tmp32_ = NULL;
							const gchar* _tmp33_ = NULL;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp26_ = _b_persona_it;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp27_ = gee_iterator_next (_tmp26_);
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							if (!_tmp27_) {
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								break;
#line 1075 "contacts-store.c"
							}
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp28_ = _b_persona_it;
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp29_ = gee_iterator_get (_tmp28_);
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							b_persona = (FolksPersona*) _tmp29_;
#line 116 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp30_ = b_persona;
#line 116 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp31_ = folks_persona_get_uid (_tmp30_);
#line 116 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp32_ = _tmp31_;
#line 116 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp33_ = no_link_uid;
#line 116 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							if (g_strcmp0 (_tmp32_, _tmp33_) == 0) {
#line 117 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								result = FALSE;
#line 117 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								_g_object_unref0 (b_persona);
#line 117 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								_g_object_unref0 (_b_persona_it);
#line 117 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								_g_free0 (no_link_uid);
#line 117 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								_g_object_unref0 (_no_link_uid_it);
#line 117 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								_g_object_unref0 (a_persona);
#line 117 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								_g_object_unref0 (_a_persona_it);
#line 117 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								return result;
#line 1109 "contacts-store.c"
							}
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_g_object_unref0 (b_persona);
#line 1113 "contacts-store.c"
						}
#line 115 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_g_object_unref0 (_b_persona_it);
#line 1117 "contacts-store.c"
					}
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_g_free0 (no_link_uid);
#line 1121 "contacts-store.c"
				}
#line 114 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_g_object_unref0 (_no_link_uid_it);
#line 1125 "contacts-store.c"
			}
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_g_object_unref0 (a_persona);
#line 1129 "contacts-store.c"
		}
#line 113 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_object_unref0 (_a_persona_it);
#line 1133 "contacts-store.c"
	}
	{
		GeeIterator* _b_persona_it = NULL;
		ContactsContact* _tmp34_ = NULL;
		FolksIndividual* _tmp35_ = NULL;
		GeeSet* _tmp36_ = NULL;
		GeeSet* _tmp37_ = NULL;
		GeeIterator* _tmp38_ = NULL;
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp34_ = b;
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp35_ = _tmp34_->individual;
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp36_ = folks_individual_get_personas (_tmp35_);
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp37_ = _tmp36_;
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp38_ = gee_iterable_iterator ((GeeIterable*) _tmp37_);
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_b_persona_it = _tmp38_;
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		while (TRUE) {
#line 1156 "contacts-store.c"
			GeeIterator* _tmp39_ = NULL;
			gboolean _tmp40_ = FALSE;
			FolksPersona* b_persona = NULL;
			GeeIterator* _tmp41_ = NULL;
			gpointer _tmp42_ = NULL;
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp39_ = _b_persona_it;
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp40_ = gee_iterator_next (_tmp39_);
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			if (!_tmp40_) {
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				break;
#line 1170 "contacts-store.c"
			}
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp41_ = _b_persona_it;
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp42_ = gee_iterator_get (_tmp41_);
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			b_persona = (FolksPersona*) _tmp42_;
#line 1178 "contacts-store.c"
			{
				GeeIterator* _no_link_uid_it = NULL;
				GeeHashMultiMap* _tmp43_ = NULL;
				FolksPersona* _tmp44_ = NULL;
				const gchar* _tmp45_ = NULL;
				const gchar* _tmp46_ = NULL;
				GeeCollection* _tmp47_ = NULL;
				GeeCollection* _tmp48_ = NULL;
				GeeIterator* _tmp49_ = NULL;
				GeeIterator* _tmp50_ = NULL;
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp43_ = self->dont_suggest_link;
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp44_ = b_persona;
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp45_ = folks_persona_get_uid (_tmp44_);
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp46_ = _tmp45_;
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp47_ = gee_multi_map_get ((GeeMultiMap*) _tmp43_, _tmp46_);
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp48_ = _tmp47_;
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp49_ = gee_iterable_iterator ((GeeIterable*) _tmp48_);
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp50_ = _tmp49_;
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_g_object_unref0 (_tmp48_);
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_no_link_uid_it = _tmp50_;
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				while (TRUE) {
#line 1211 "contacts-store.c"
					GeeIterator* _tmp51_ = NULL;
					gboolean _tmp52_ = FALSE;
					gchar* no_link_uid = NULL;
					GeeIterator* _tmp53_ = NULL;
					gpointer _tmp54_ = NULL;
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp51_ = _no_link_uid_it;
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp52_ = gee_iterator_next (_tmp51_);
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					if (!_tmp52_) {
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						break;
#line 1225 "contacts-store.c"
					}
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp53_ = _no_link_uid_it;
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp54_ = gee_iterator_get (_tmp53_);
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					no_link_uid = (gchar*) _tmp54_;
#line 1233 "contacts-store.c"
					{
						GeeIterator* _a_persona_it = NULL;
						ContactsContact* _tmp55_ = NULL;
						FolksIndividual* _tmp56_ = NULL;
						GeeSet* _tmp57_ = NULL;
						GeeSet* _tmp58_ = NULL;
						GeeIterator* _tmp59_ = NULL;
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp55_ = a;
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp56_ = _tmp55_->individual;
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp57_ = folks_individual_get_personas (_tmp56_);
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp58_ = _tmp57_;
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp59_ = gee_iterable_iterator ((GeeIterable*) _tmp58_);
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_a_persona_it = _tmp59_;
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						while (TRUE) {
#line 1255 "contacts-store.c"
							GeeIterator* _tmp60_ = NULL;
							gboolean _tmp61_ = FALSE;
							FolksPersona* a_persona = NULL;
							GeeIterator* _tmp62_ = NULL;
							gpointer _tmp63_ = NULL;
							FolksPersona* _tmp64_ = NULL;
							const gchar* _tmp65_ = NULL;
							const gchar* _tmp66_ = NULL;
							const gchar* _tmp67_ = NULL;
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp60_ = _a_persona_it;
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp61_ = gee_iterator_next (_tmp60_);
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							if (!_tmp61_) {
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								break;
#line 1273 "contacts-store.c"
							}
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp62_ = _a_persona_it;
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp63_ = gee_iterator_get (_tmp62_);
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							a_persona = (FolksPersona*) _tmp63_;
#line 124 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp64_ = a_persona;
#line 124 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp65_ = folks_persona_get_uid (_tmp64_);
#line 124 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp66_ = _tmp65_;
#line 124 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp67_ = no_link_uid;
#line 124 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							if (g_strcmp0 (_tmp66_, _tmp67_) == 0) {
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								result = FALSE;
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								_g_object_unref0 (a_persona);
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								_g_object_unref0 (_a_persona_it);
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								_g_free0 (no_link_uid);
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								_g_object_unref0 (_no_link_uid_it);
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								_g_object_unref0 (b_persona);
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								_g_object_unref0 (_b_persona_it);
#line 125 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								return result;
#line 1307 "contacts-store.c"
							}
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_g_object_unref0 (a_persona);
#line 1311 "contacts-store.c"
						}
#line 123 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_g_object_unref0 (_a_persona_it);
#line 1315 "contacts-store.c"
					}
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_g_free0 (no_link_uid);
#line 1319 "contacts-store.c"
				}
#line 122 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_g_object_unref0 (_no_link_uid_it);
#line 1323 "contacts-store.c"
			}
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_g_object_unref0 (b_persona);
#line 1327 "contacts-store.c"
		}
#line 121 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_object_unref0 (_b_persona_it);
#line 1331 "contacts-store.c"
	}
#line 129 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	result = TRUE;
#line 129 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return result;
#line 1337 "contacts-store.c"
}


void contacts_store_add_no_suggest_link (ContactsStore* self, ContactsContact* a, ContactsContact* b) {
	FolksPersona* persona1 = NULL;
	ContactsContact* _tmp0_ = NULL;
	GeeList* _tmp1_ = NULL;
	GeeList* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gpointer* _tmp4_ = NULL;
	FolksPersona** _tmp5_ = NULL;
	gint _tmp5__length1 = 0;
	FolksPersona* _tmp6_ = NULL;
	FolksPersona* _tmp7_ = NULL;
	FolksPersona* _tmp8_ = NULL;
	FolksPersona* persona2 = NULL;
	ContactsContact* _tmp9_ = NULL;
	GeeList* _tmp10_ = NULL;
	GeeList* _tmp11_ = NULL;
	gint _tmp12_ = 0;
	gpointer* _tmp13_ = NULL;
	FolksPersona** _tmp14_ = NULL;
	gint _tmp14__length1 = 0;
	FolksPersona* _tmp15_ = NULL;
	FolksPersona* _tmp16_ = NULL;
	FolksPersona* _tmp17_ = NULL;
	GeeHashMultiMap* _tmp18_ = NULL;
	const gchar* _tmp19_ = NULL;
	const gchar* _tmp20_ = NULL;
	const gchar* _tmp21_ = NULL;
	const gchar* _tmp22_ = NULL;
#line 132 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (self != NULL);
#line 132 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (a != NULL);
#line 132 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (b != NULL);
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = a;
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp1_ = contacts_contact_get_personas_for_display (_tmp0_);
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp2_ = _tmp1_;
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp4_ = gee_collection_to_array ((GeeCollection*) _tmp2_, &_tmp3_);
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp5_ = _tmp4_;
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp5__length1 = _tmp3_;
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp6_ = _tmp5_[0];
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp8_ = _tmp7_;
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp5_ = (_vala_array_free (_tmp5_, _tmp5__length1, (GDestroyNotify) g_object_unref), NULL);
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (_tmp2_);
#line 133 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	persona1 = _tmp8_;
#line 134 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp9_ = b;
#line 134 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp10_ = contacts_contact_get_personas_for_display (_tmp9_);
#line 134 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp11_ = _tmp10_;
#line 134 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp13_ = gee_collection_to_array ((GeeCollection*) _tmp11_, &_tmp12_);
#line 134 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp14_ = _tmp13_;
#line 134 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp14__length1 = _tmp12_;
#line 134 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp15_ = _tmp14_[0];
#line 134 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp16_ = _g_object_ref0 (_tmp15_);
#line 134 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp17_ = _tmp16_;
#line 134 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp14_ = (_vala_array_free (_tmp14_, _tmp14__length1, (GDestroyNotify) g_object_unref), NULL);
#line 134 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (_tmp11_);
#line 134 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	persona2 = _tmp17_;
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp18_ = self->dont_suggest_link;
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp19_ = folks_persona_get_uid (persona1);
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp20_ = _tmp19_;
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp21_ = folks_persona_get_uid (persona2);
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp22_ = _tmp21_;
#line 135 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	gee_multi_map_set ((GeeMultiMap*) _tmp18_, _tmp20_, _tmp22_);
#line 136 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	contacts_store_write_dont_suggest_db (self);
#line 132 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (persona2);
#line 132 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (persona1);
#line 1441 "contacts-store.c"
}


static void contacts_store_contact_changed_cb (ContactsStore* self, ContactsContact* c) {
	ContactsContact* _tmp0_ = NULL;
#line 245 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (self != NULL);
#line 245 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (c != NULL);
#line 246 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = c;
#line 246 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_emit_by_name (self, "changed", _tmp0_);
#line 1455 "contacts-store.c"
}


static void contacts_store_find_contact_data_free (gpointer _data) {
	ContactsStoreFindContactData* _data_;
	_data_ = _data;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (_data_->result);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (_data_->self);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_slice_free (ContactsStoreFindContactData, _data_);
#line 1468 "contacts-store.c"
}


void contacts_store_find_contact (ContactsStore* self, ContactsStoreContactMatcher matcher, void* matcher_target, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	ContactsStoreFindContactData* _data_;
	ContactsStore* _tmp0_ = NULL;
	ContactsStoreContactMatcher _tmp1_ = NULL;
	void* _tmp1__target = NULL;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_ = g_slice_new0 (ContactsStoreFindContactData);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, contacts_store_find_contact);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, contacts_store_find_contact_data_free);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->self = _tmp0_;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp1_ = matcher;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp1__target = matcher_target;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->matcher = _tmp1_;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->matcher_target = _tmp1__target;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	contacts_store_find_contact_co (_data_);
#line 1497 "contacts-store.c"
}


ContactsContact* contacts_store_find_contact_finish (ContactsStore* self, GAsyncResult* _res_) {
	ContactsContact* result;
	ContactsStoreFindContactData* _data_;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	result = _data_->result;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->result = NULL;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return result;
#line 1512 "contacts-store.c"
}


static Block35Data* block35_data_ref (Block35Data* _data35_) {
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_atomic_int_inc (&_data35_->_ref_count_);
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return _data35_;
#line 1521 "contacts-store.c"
}


static void block35_data_unref (void * _userdata_) {
	Block35Data* _data35_;
	_data35_ = (Block35Data*) _userdata_;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	if (g_atomic_int_dec_and_test (&_data35_->_ref_count_)) {
#line 1530 "contacts-store.c"
		ContactsStore* self;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		self = _data35_->self;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		(_data35_->callback_target_destroy_notify == NULL) ? NULL : (_data35_->callback_target_destroy_notify (_data35_->callback_target), NULL);
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data35_->callback = NULL;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data35_->callback_target = NULL;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data35_->callback_target_destroy_notify = NULL;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_object_unref0 (_data35_->matched);
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_object_unref0 (self);
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_slice_free (Block35Data, _data35_);
#line 1548 "contacts-store.c"
	}
}


static gboolean _contacts_store_find_contact_co_gsource_func (gpointer self) {
	gboolean result;
	result = contacts_store_find_contact_co (self);
#line 260 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return result;
#line 1558 "contacts-store.c"
}


static void __lambda17_ (Block35Data* _data35_, ContactsContact* c) {
	ContactsStore* self;
	ContactsStoreContactMatcher _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	ContactsContact* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
#line 261 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	self = _data35_->self;
#line 261 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (c != NULL);
#line 262 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = _data35_->matcher;
#line 262 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0__target = _data35_->matcher_target;
#line 262 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp1_ = c;
#line 262 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp2_ = _tmp0_ (_tmp1_, _tmp0__target);
#line 262 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	if (_tmp2_) {
#line 1582 "contacts-store.c"
		ContactsContact* _tmp3_ = NULL;
		ContactsContact* _tmp4_ = NULL;
		GSourceFunc _tmp5_ = NULL;
		void* _tmp5__target = NULL;
#line 263 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp3_ = c;
#line 263 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp4_ = _g_object_ref0 (_tmp3_);
#line 263 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_object_unref0 (_data35_->matched);
#line 263 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data35_->matched = _tmp4_;
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp5_ = _data35_->callback;
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp5__target = _data35_->callback_target;
#line 264 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp5_ (_tmp5__target);
#line 1601 "contacts-store.c"
	}
}


static void ___lambda17__contacts_store_changed (ContactsStore* _sender, ContactsContact* c, gpointer self) {
#line 261 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	__lambda17_ (self, c);
#line 1609 "contacts-store.c"
}


static void __lambda18_ (Block35Data* _data35_, ContactsContact* c) {
	ContactsStore* self;
	ContactsStoreContactMatcher _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	ContactsContact* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
#line 267 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	self = _data35_->self;
#line 267 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (c != NULL);
#line 268 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = _data35_->matcher;
#line 268 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0__target = _data35_->matcher_target;
#line 268 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp1_ = c;
#line 268 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp2_ = _tmp0_ (_tmp1_, _tmp0__target);
#line 268 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	if (_tmp2_) {
#line 1633 "contacts-store.c"
		ContactsContact* _tmp3_ = NULL;
		ContactsContact* _tmp4_ = NULL;
		GSourceFunc _tmp5_ = NULL;
		void* _tmp5__target = NULL;
#line 269 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp3_ = c;
#line 269 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp4_ = _g_object_ref0 (_tmp3_);
#line 269 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_object_unref0 (_data35_->matched);
#line 269 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data35_->matched = _tmp4_;
#line 270 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp5_ = _data35_->callback;
#line 270 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp5__target = _data35_->callback_target;
#line 270 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp5_ (_tmp5__target);
#line 1652 "contacts-store.c"
	}
}


static void ___lambda18__contacts_store_added (ContactsStore* _sender, ContactsContact* c, gpointer self) {
#line 267 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	__lambda18_ (self, c);
#line 1660 "contacts-store.c"
}


static void __lambda19_ (Block35Data* _data35_) {
	ContactsStore* self;
	GSourceFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
#line 273 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	self = _data35_->self;
#line 274 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = _data35_->callback;
#line 274 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0__target = _data35_->callback_target;
#line 274 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ (_tmp0__target);
#line 1676 "contacts-store.c"
}


static void ___lambda19__contacts_store_quiescent (ContactsStore* _sender, gpointer self) {
#line 273 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	__lambda19_ (self);
#line 1683 "contacts-store.c"
}


static gboolean contacts_store_find_contact_co (ContactsStoreFindContactData* _data_) {
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	switch (_data_->_state_) {
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		case 0:
#line 1692 "contacts-store.c"
		goto _state_0;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		case 1:
#line 1696 "contacts-store.c"
		goto _state_1;
		default:
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_assert_not_reached ();
#line 1701 "contacts-store.c"
	}
	_state_0:
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_data35_ = g_slice_new0 (Block35Data);
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_data35_->_ref_count_ = 1;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_data35_->self = g_object_ref (_data_->self);
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp0_ = NULL;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp0__target = NULL;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp0_ = _data_->matcher;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp0__target = _data_->matcher_target;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_data35_->matcher = _data_->_tmp0_;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_data35_->matcher_target = _data_->_tmp0__target;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_data35_->_async_data_ = _data_;
#line 1724 "contacts-store.c"
	{
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp1_ = NULL;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp1_ = _data_->self->priv->contacts;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp2_ = NULL;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp2_ = _g_object_ref0 (_data_->_tmp1_);
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_c_list = _data_->_tmp2_;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp3_ = NULL;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp3_ = _data_->_c_list;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp4_ = 0;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp4_ = gee_abstract_collection_get_size ((GeeCollection*) _data_->_tmp3_);
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp5_ = 0;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp5_ = _data_->_tmp4_;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_c_size = _data_->_tmp5_;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_c_index = -1;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		while (TRUE) {
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp6_ = 0;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp6_ = _data_->_c_index;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_c_index = _data_->_tmp6_ + 1;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp7_ = 0;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp7_ = _data_->_c_index;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp8_ = 0;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp8_ = _data_->_c_size;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			if (!(_data_->_tmp7_ < _data_->_tmp8_)) {
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				break;
#line 1772 "contacts-store.c"
			}
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp9_ = NULL;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp9_ = _data_->_c_list;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp10_ = 0;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp10_ = _data_->_c_index;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp11_ = NULL;
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp11_ = gee_abstract_list_get ((GeeAbstractList*) _data_->_tmp9_, _data_->_tmp10_);
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->c = (ContactsContact*) _data_->_tmp11_;
#line 252 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp12_ = NULL;
#line 252 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp12__target = NULL;
#line 252 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp12_ = _data_->_data35_->matcher;
#line 252 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp12__target = _data_->_data35_->matcher_target;
#line 252 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp13_ = NULL;
#line 252 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp13_ = _data_->c;
#line 252 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp14_ = FALSE;
#line 252 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp14_ = _data_->_tmp12_ (_data_->_tmp13_, _data_->_tmp12__target);
#line 252 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			if (_data_->_tmp14_) {
#line 253 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_data_->result = _data_->c;
#line 253 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_g_object_unref0 (_data_->_c_list);
#line 253 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				block35_data_unref (_data_->_data35_);
#line 253 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_data_->_data35_ = NULL;
#line 253 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				if (_data_->_state_ == 0) {
#line 253 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1818 "contacts-store.c"
				} else {
#line 253 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 1822 "contacts-store.c"
				}
#line 253 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				g_object_unref (_data_->_async_result);
#line 253 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				return FALSE;
#line 1828 "contacts-store.c"
			}
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_g_object_unref0 (_data_->c);
#line 1832 "contacts-store.c"
		}
#line 251 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_object_unref0 (_data_->_c_list);
#line 1836 "contacts-store.c"
	}
#line 255 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp15_ = FALSE;
#line 255 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp15_ = contacts_store_get_is_quiescent (_data_->self);
#line 255 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp16_ = FALSE;
#line 255 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp16_ = _data_->_tmp15_;
#line 255 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	if (_data_->_tmp16_) {
#line 256 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->result = NULL;
#line 256 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		block35_data_unref (_data_->_data35_);
#line 256 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_data35_ = NULL;
#line 256 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		if (_data_->_state_ == 0) {
#line 256 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1858 "contacts-store.c"
		} else {
#line 256 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1862 "contacts-store.c"
		}
#line 256 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_object_unref (_data_->_async_result);
#line 256 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		return FALSE;
#line 1868 "contacts-store.c"
	}
#line 258 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_data35_->matched = NULL;
#line 260 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_data35_->callback = _contacts_store_find_contact_co_gsource_func;
#line 260 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_data35_->callback_target = _data_;
#line 260 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_data35_->callback_target_destroy_notify = NULL;
#line 261 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp17_ = 0UL;
#line 261 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp17_ = g_signal_connect_data (_data_->self, "changed", (GCallback) ___lambda17__contacts_store_changed, block35_data_ref (_data_->_data35_), (GClosureNotify) block35_data_unref, 0);
#line 261 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->id1 = _data_->_tmp17_;
#line 267 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp18_ = 0UL;
#line 267 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp18_ = g_signal_connect_data (_data_->self, "added", (GCallback) ___lambda18__contacts_store_added, block35_data_ref (_data_->_data35_), (GClosureNotify) block35_data_unref, 0);
#line 267 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->id2 = _data_->_tmp18_;
#line 273 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp19_ = 0UL;
#line 273 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp19_ = g_signal_connect_data (_data_->self, "quiescent", (GCallback) ___lambda19__contacts_store_quiescent, block35_data_ref (_data_->_data35_), (GClosureNotify) block35_data_unref, 0);
#line 273 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->id3 = _data_->_tmp19_;
#line 276 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_state_ = 1;
#line 276 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return FALSE;
#line 1900 "contacts-store.c"
	_state_1:
	;
#line 277 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp20_ = 0UL;
#line 277 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp20_ = _data_->id1;
#line 277 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_handler_disconnect ((GObject*) _data_->self, _data_->_tmp20_);
#line 278 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp21_ = 0UL;
#line 278 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp21_ = _data_->id2;
#line 278 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_handler_disconnect ((GObject*) _data_->self, _data_->_tmp21_);
#line 279 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp22_ = 0UL;
#line 279 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp22_ = _data_->id3;
#line 279 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_handler_disconnect ((GObject*) _data_->self, _data_->_tmp22_);
#line 280 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp23_ = NULL;
#line 280 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp23_ = _data_->_data35_->matched;
#line 280 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp24_ = NULL;
#line 280 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp24_ = _g_object_ref0 (_data_->_tmp23_);
#line 280 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->result = _data_->_tmp24_;
#line 280 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	block35_data_unref (_data_->_data35_);
#line 280 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_data35_ = NULL;
#line 280 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	if (_data_->_state_ == 0) {
#line 280 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1939 "contacts-store.c"
	} else {
#line 280 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1943 "contacts-store.c"
	}
#line 280 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_object_unref (_data_->_async_result);
#line 280 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return FALSE;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	block35_data_unref (_data_->_data35_);
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_data35_ = NULL;
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	if (_data_->_state_ == 0) {
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1957 "contacts-store.c"
	} else {
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1961 "contacts-store.c"
	}
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_object_unref (_data_->_async_result);
#line 250 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return FALSE;
#line 1967 "contacts-store.c"
}


ContactsContact* contacts_store_find_contact_with_persona (ContactsStore* self, FolksPersona* persona) {
	ContactsContact* result = NULL;
#line 283 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 283 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_val_if_fail (persona != NULL, NULL);
#line 1977 "contacts-store.c"
	{
		GeeArrayList* _contact_list = NULL;
		GeeArrayList* _tmp0_ = NULL;
		GeeArrayList* _tmp1_ = NULL;
		gint _contact_size = 0;
		GeeArrayList* _tmp2_ = NULL;
		gint _tmp3_ = 0;
		gint _tmp4_ = 0;
		gint _contact_index = 0;
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp0_ = self->priv->contacts;
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_contact_list = _tmp1_;
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp2_ = _contact_list;
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp3_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp2_);
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp4_ = _tmp3_;
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_contact_size = _tmp4_;
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_contact_index = -1;
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		while (TRUE) {
#line 2005 "contacts-store.c"
			gint _tmp5_ = 0;
			gint _tmp6_ = 0;
			gint _tmp7_ = 0;
			ContactsContact* contact = NULL;
			GeeArrayList* _tmp8_ = NULL;
			gint _tmp9_ = 0;
			gpointer _tmp10_ = NULL;
			ContactsContact* _tmp11_ = NULL;
			FolksIndividual* _tmp12_ = NULL;
			GeeSet* _tmp13_ = NULL;
			GeeSet* _tmp14_ = NULL;
			FolksPersona* _tmp15_ = NULL;
			gboolean _tmp16_ = FALSE;
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp5_ = _contact_index;
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_contact_index = _tmp5_ + 1;
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp6_ = _contact_index;
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp7_ = _contact_size;
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			if (!(_tmp6_ < _tmp7_)) {
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				break;
#line 2031 "contacts-store.c"
			}
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp8_ = _contact_list;
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp9_ = _contact_index;
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp10_ = gee_abstract_list_get ((GeeAbstractList*) _tmp8_, _tmp9_);
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			contact = (ContactsContact*) _tmp10_;
#line 285 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp11_ = contact;
#line 285 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp12_ = _tmp11_->individual;
#line 285 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp13_ = folks_individual_get_personas (_tmp12_);
#line 285 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp14_ = _tmp13_;
#line 285 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp15_ = persona;
#line 285 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp16_ = gee_collection_contains ((GeeCollection*) _tmp14_, _tmp15_);
#line 285 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			if (_tmp16_) {
#line 286 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				result = contact;
#line 286 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_g_object_unref0 (_contact_list);
#line 286 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				return result;
#line 2061 "contacts-store.c"
			}
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_g_object_unref0 (contact);
#line 2065 "contacts-store.c"
		}
#line 284 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_object_unref0 (_contact_list);
#line 2069 "contacts-store.c"
	}
#line 288 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	result = NULL;
#line 288 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return result;
#line 2075 "contacts-store.c"
}


GeeCollection* contacts_store_get_contacts (ContactsStore* self) {
	GeeCollection* result = NULL;
	GeeArrayList* _tmp0_ = NULL;
	GeeBidirList* _tmp1_ = NULL;
	GeeBidirList* _tmp2_ = NULL;
#line 291 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 292 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = self->priv->contacts;
#line 292 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp1_ = gee_abstract_bidir_list_get_read_only_view ((GeeAbstractBidirList*) _tmp0_);
#line 292 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp2_ = _tmp1_;
#line 292 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	result = (GeeCollection*) _tmp2_;
#line 292 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return result;
#line 2096 "contacts-store.c"
}


gboolean contacts_store_is_empty (ContactsStore* self) {
	gboolean result = FALSE;
#line 295 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 2104 "contacts-store.c"
	{
		GeeArrayList* _contact_list = NULL;
		GeeArrayList* _tmp0_ = NULL;
		GeeArrayList* _tmp1_ = NULL;
		gint _contact_size = 0;
		GeeArrayList* _tmp2_ = NULL;
		gint _tmp3_ = 0;
		gint _tmp4_ = 0;
		gint _contact_index = 0;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp0_ = self->priv->contacts;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_contact_list = _tmp1_;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp2_ = _contact_list;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp3_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp2_);
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp4_ = _tmp3_;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_contact_size = _tmp4_;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_contact_index = -1;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		while (TRUE) {
#line 2132 "contacts-store.c"
			gint _tmp5_ = 0;
			gint _tmp6_ = 0;
			gint _tmp7_ = 0;
			ContactsContact* contact = NULL;
			GeeArrayList* _tmp8_ = NULL;
			gint _tmp9_ = 0;
			gpointer _tmp10_ = NULL;
			ContactsContact* _tmp11_ = NULL;
			gboolean _tmp12_ = FALSE;
			gboolean _tmp13_ = FALSE;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp5_ = _contact_index;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_contact_index = _tmp5_ + 1;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp6_ = _contact_index;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp7_ = _contact_size;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			if (!(_tmp6_ < _tmp7_)) {
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				break;
#line 2155 "contacts-store.c"
			}
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp8_ = _contact_list;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp9_ = _contact_index;
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp10_ = gee_abstract_list_get ((GeeAbstractList*) _tmp8_, _tmp9_);
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			contact = (ContactsContact*) _tmp10_;
#line 297 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp11_ = contact;
#line 297 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp12_ = contacts_contact_get_is_hidden (_tmp11_);
#line 297 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp13_ = _tmp12_;
#line 297 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			if (!_tmp13_) {
#line 298 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				result = FALSE;
#line 298 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_g_object_unref0 (contact);
#line 298 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_g_object_unref0 (_contact_list);
#line 298 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				return result;
#line 2181 "contacts-store.c"
			}
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_g_object_unref0 (contact);
#line 2185 "contacts-store.c"
		}
#line 296 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_object_unref0 (_contact_list);
#line 2189 "contacts-store.c"
	}
#line 300 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	result = TRUE;
#line 300 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return result;
#line 2195 "contacts-store.c"
}


static void _contacts_store_contact_changed_cb_contacts_contact_changed (ContactsContact* _sender, gpointer self) {
#line 305 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	contacts_store_contact_changed_cb ((ContactsStore*) self, _sender);
#line 2202 "contacts-store.c"
}


static void contacts_store_add (ContactsStore* self, ContactsContact* c) {
	GeeArrayList* _tmp0_ = NULL;
	ContactsContact* _tmp1_ = NULL;
	ContactsContact* _tmp2_ = NULL;
	ContactsContact* _tmp3_ = NULL;
#line 303 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (self != NULL);
#line 303 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (c != NULL);
#line 304 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = self->priv->contacts;
#line 304 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp1_ = c;
#line 304 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp0_, _tmp1_);
#line 305 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp2_ = c;
#line 305 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_connect_object (_tmp2_, "changed", (GCallback) _contacts_store_contact_changed_cb_contacts_contact_changed, self, 0);
#line 306 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp3_ = c;
#line 306 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_emit_by_name (self, "added", _tmp3_);
#line 2229 "contacts-store.c"
}


static void contacts_store_remove (ContactsStore* self, ContactsContact* c) {
	ContactsContact* _tmp0_ = NULL;
	guint _tmp1_ = 0U;
	gint i = 0;
	GeeArrayList* _tmp2_ = NULL;
	ContactsContact* _tmp3_ = NULL;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	GeeArrayList* _tmp6_ = NULL;
	gint _tmp7_ = 0;
	gint _tmp8_ = 0;
	GeeArrayList* _tmp17_ = NULL;
	GeeArrayList* _tmp18_ = NULL;
	gint _tmp19_ = 0;
	gint _tmp20_ = 0;
	gpointer _tmp21_ = NULL;
	ContactsContact* _tmp22_ = NULL;
	ContactsContact* _tmp23_ = NULL;
#line 309 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (self != NULL);
#line 309 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (c != NULL);
#line 310 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = c;
#line 310 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_parse_name ("changed", CONTACTS_TYPE_CONTACT, &_tmp1_, NULL, FALSE);
#line 310 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_handlers_disconnect_matched (_tmp0_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp1_, 0, NULL, (GCallback) _contacts_store_contact_changed_cb_contacts_contact_changed, self);
#line 312 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp2_ = self->priv->contacts;
#line 312 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp3_ = c;
#line 312 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp4_ = gee_abstract_list_index_of ((GeeAbstractList*) _tmp2_, _tmp3_);
#line 312 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	i = _tmp4_;
#line 313 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp5_ = i;
#line 313 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp6_ = self->priv->contacts;
#line 313 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp7_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp6_);
#line 313 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp8_ = _tmp7_;
#line 313 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	if (_tmp5_ != (_tmp8_ - 1)) {
#line 2279 "contacts-store.c"
		GeeArrayList* _tmp9_ = NULL;
		gint _tmp10_ = 0;
		GeeArrayList* _tmp11_ = NULL;
		GeeArrayList* _tmp12_ = NULL;
		gint _tmp13_ = 0;
		gint _tmp14_ = 0;
		gpointer _tmp15_ = NULL;
		ContactsContact* _tmp16_ = NULL;
#line 314 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp9_ = self->priv->contacts;
#line 314 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp10_ = i;
#line 314 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp11_ = self->priv->contacts;
#line 314 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp12_ = self->priv->contacts;
#line 314 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp13_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp12_);
#line 314 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp14_ = _tmp13_;
#line 314 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp15_ = gee_abstract_list_get ((GeeAbstractList*) _tmp11_, _tmp14_ - 1);
#line 314 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp16_ = (ContactsContact*) _tmp15_;
#line 314 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		gee_abstract_list_set ((GeeAbstractList*) _tmp9_, _tmp10_, _tmp16_);
#line 314 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_object_unref0 (_tmp16_);
#line 2308 "contacts-store.c"
	}
#line 315 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp17_ = self->priv->contacts;
#line 315 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp18_ = self->priv->contacts;
#line 315 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp19_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp18_);
#line 315 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp20_ = _tmp19_;
#line 315 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp21_ = gee_abstract_list_remove_at ((GeeAbstractList*) _tmp17_, _tmp20_ - 1);
#line 315 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp22_ = (ContactsContact*) _tmp21_;
#line 315 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (_tmp22_);
#line 317 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp23_ = c;
#line 317 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_emit_by_name (self, "removed", _tmp23_);
#line 2328 "contacts-store.c"
}


static void contacts_store_check_call_capabilities_data_free (gpointer _data) {
	ContactsStoreCheckCallCapabilitiesData* _data_;
	_data_ = _data;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (_data_->self);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_slice_free (ContactsStoreCheckCallCapabilitiesData, _data_);
#line 2339 "contacts-store.c"
}


static void contacts_store_check_call_capabilities (ContactsStore* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	ContactsStoreCheckCallCapabilitiesData* _data_;
	ContactsStore* _tmp0_ = NULL;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_ = g_slice_new0 (ContactsStoreCheckCallCapabilitiesData);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, contacts_store_check_call_capabilities);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, contacts_store_check_call_capabilities_data_free);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->self = _tmp0_;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	contacts_store_check_call_capabilities_co (_data_);
#line 2358 "contacts-store.c"
}


static void contacts_store_check_call_capabilities_finish (ContactsStore* self, GAsyncResult* _res_) {
	ContactsStoreCheckCallCapabilitiesData* _data_;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2366 "contacts-store.c"
}


static void contacts_store_check_call_capabilities_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	ContactsStoreCheckCallCapabilitiesData* _data_;
#line 326 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_ = _user_data_;
#line 326 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_source_object_ = source_object;
#line 326 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_res_ = _res_;
#line 326 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	contacts_store_check_call_capabilities_co (_data_);
#line 2380 "contacts-store.c"
}


static void _contacts_store_check_account_caps_tp_account_manager_account_enabled (TpAccountManager* _sender, TpAccount* account, gpointer self) {
#line 328 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	contacts_store_check_account_caps ((ContactsStore*) self, account, NULL, NULL);
#line 2387 "contacts-store.c"
}


static void _contacts_store_check_account_caps_tp_account_manager_account_disabled (TpAccountManager* _sender, TpAccount* account, gpointer self) {
#line 329 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	contacts_store_check_account_caps ((ContactsStore*) self, account, NULL, NULL);
#line 2394 "contacts-store.c"
}


static gboolean contacts_store_check_call_capabilities_co (ContactsStoreCheckCallCapabilitiesData* _data_) {
#line 321 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	switch (_data_->_state_) {
#line 321 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		case 0:
#line 2403 "contacts-store.c"
		goto _state_0;
#line 321 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		case 1:
#line 2407 "contacts-store.c"
		goto _state_1;
#line 321 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		case 2:
#line 2411 "contacts-store.c"
		goto _state_2;
		default:
#line 321 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_assert_not_reached ();
#line 2416 "contacts-store.c"
	}
	_state_0:
#line 322 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp0_ = NULL;
#line 322 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, tp_account_get_type (), (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 322 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (_data_->self->calling_accounts);
#line 322 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->self->calling_accounts = _data_->_tmp0_;
#line 323 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp1_ = NULL;
#line 323 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp1_ = tp_account_manager_dup ();
#line 323 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->account_manager = _data_->_tmp1_;
#line 2433 "contacts-store.c"
	{
#line 326 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_state_ = 1;
#line 326 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		tp_proxy_prepare_async ((TpProxy*) _data_->account_manager, NULL, contacts_store_check_call_capabilities_ready, _data_);
#line 326 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		return FALSE;
#line 2441 "contacts-store.c"
		_state_1:
#line 326 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		tp_proxy_prepare_finish ((TpProxy*) _data_->account_manager, _data_->_res_, &_data_->_inner_error_);
#line 326 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 2447 "contacts-store.c"
			goto __catch26_g_error;
		}
#line 328 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_signal_connect_object (_data_->account_manager, "account-enabled", (GCallback) _contacts_store_check_account_caps_tp_account_manager_account_enabled, _data_->self, 0);
#line 329 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_signal_connect_object (_data_->account_manager, "account-disabled", (GCallback) _contacts_store_check_account_caps_tp_account_manager_account_disabled, _data_->self, 0);
#line 331 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp2_ = NULL;
#line 331 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp2_ = tp_account_manager_get_valid_accounts (_data_->account_manager);
#line 2458 "contacts-store.c"
		{
#line 331 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->account_collection = _data_->_tmp2_;
#line 331 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			for (_data_->account_it = _data_->account_collection; _data_->account_it != NULL; _data_->account_it = _data_->account_it->next) {
#line 331 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_data_->account = (TpAccount*) _data_->account_it->data;
#line 2466 "contacts-store.c"
				{
#line 332 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_data_->_tmp3_ = NULL;
#line 332 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_data_->_tmp3_ = _data_->account;
#line 332 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_data_->_state_ = 2;
#line 332 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					contacts_store_check_account_caps (_data_->self, _data_->_tmp3_, contacts_store_check_call_capabilities_ready, _data_);
#line 332 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					return FALSE;
#line 2478 "contacts-store.c"
					_state_2:
#line 332 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					contacts_store_check_account_caps_finish (_data_->self, _data_->_res_);
#line 2482 "contacts-store.c"
				}
			}
#line 331 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_g_list_free0 (_data_->account_collection);
#line 2487 "contacts-store.c"
		}
	}
	goto __finally26;
	__catch26_g_error:
	{
#line 325 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->e = _data_->_inner_error_;
#line 325 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_inner_error_ = NULL;
#line 335 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp4_ = NULL;
#line 335 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp4_ = _data_->e;
#line 335 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp5_ = NULL;
#line 335 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp5_ = _data_->_tmp4_->message;
#line 335 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_warning ("contacts-store.vala:335: Unable to check accounts caps %s", _data_->_tmp5_);
#line 325 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_error_free0 (_data_->e);
#line 2509 "contacts-store.c"
	}
	__finally26:
#line 325 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 325 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_object_unref0 (_data_->account_manager);
#line 325 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 325 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_clear_error (&_data_->_inner_error_);
#line 325 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		return FALSE;
#line 2522 "contacts-store.c"
	}
#line 321 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (_data_->account_manager);
#line 321 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	if (_data_->_state_ == 0) {
#line 321 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2530 "contacts-store.c"
	} else {
#line 321 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2534 "contacts-store.c"
	}
#line 321 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_object_unref (_data_->_async_result);
#line 321 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return FALSE;
#line 2540 "contacts-store.c"
}


static void contacts_store_check_account_caps_data_free (gpointer _data) {
	ContactsStoreCheckAccountCapsData* _data_;
	_data_ = _data;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (_data_->account);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (_data_->self);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_slice_free (ContactsStoreCheckAccountCapsData, _data_);
#line 2553 "contacts-store.c"
}


static void contacts_store_check_account_caps (ContactsStore* self, TpAccount* account, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	ContactsStoreCheckAccountCapsData* _data_;
	ContactsStore* _tmp0_ = NULL;
	TpAccount* _tmp1_ = NULL;
	TpAccount* _tmp2_ = NULL;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_ = g_slice_new0 (ContactsStoreCheckAccountCapsData);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, contacts_store_check_account_caps);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, contacts_store_check_account_caps_data_free);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->self = _tmp0_;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp1_ = account;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (_data_->account);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->account = _tmp2_;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	contacts_store_check_account_caps_co (_data_);
#line 2582 "contacts-store.c"
}


static void contacts_store_check_account_caps_finish (ContactsStore* self, GAsyncResult* _res_) {
	ContactsStoreCheckAccountCapsData* _data_;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2590 "contacts-store.c"
}


static void contacts_store_check_account_caps_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	ContactsStoreCheckAccountCapsData* _data_;
#line 344 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_ = _user_data_;
#line 344 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_source_object_ = source_object;
#line 344 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_res_ = _res_;
#line 344 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	contacts_store_check_account_caps_co (_data_);
#line 2604 "contacts-store.c"
}


static gboolean contacts_store_check_account_caps_co (ContactsStoreCheckAccountCapsData* _data_) {
#line 339 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	switch (_data_->_state_) {
#line 339 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		case 0:
#line 2613 "contacts-store.c"
		goto _state_0;
#line 339 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		case 1:
#line 2617 "contacts-store.c"
		goto _state_1;
		default:
#line 339 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_assert_not_reached ();
#line 2622 "contacts-store.c"
	}
	_state_0:
#line 340 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp0_ = 0U;
#line 340 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp0_ = tp_account_get_feature_quark_addressing ();
#line 340 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->addressing = _data_->_tmp0_;
#line 341 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp1_ = NULL;
#line 341 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp1_ = _data_->account;
#line 341 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp2_ = 0U;
#line 341 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp2_ = _data_->addressing;
#line 341 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp3_ = FALSE;
#line 341 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp3_ = tp_proxy_is_prepared ((TpProxy*) _data_->_tmp1_, _data_->_tmp2_);
#line 341 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	if (!_data_->_tmp3_) {
#line 342 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp4_ = 0U;
#line 342 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp4_ = _data_->addressing;
#line 342 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp5_ = NULL;
#line 342 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp5_ = g_new0 (GQuark, 1);
#line 342 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp5_[0] = _data_->_tmp4_;
#line 342 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->features_length1 = 0;
#line 342 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_features_size_ = 0;
#line 342 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->features = _data_->_tmp5_;
#line 342 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->features_length1 = 1;
#line 342 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_features_size_ = _data_->features_length1;
#line 2665 "contacts-store.c"
		{
#line 344 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp6_ = NULL;
#line 344 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp6_ = _data_->account;
#line 344 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp7_ = NULL;
#line 344 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp7__length1 = 0;
#line 344 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp7_ = _data_->features;
#line 344 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp7__length1 = _data_->features_length1;
#line 344 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_state_ = 1;
#line 344 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			tp_proxy_prepare_async ((TpProxy*) _data_->_tmp6_, _data_->_tmp7_, contacts_store_check_account_caps_ready, _data_);
#line 344 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			return FALSE;
#line 2685 "contacts-store.c"
			_state_1:
#line 344 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			tp_proxy_prepare_finish ((TpProxy*) _data_->_tmp6_, _data_->_res_, &_data_->_inner_error_);
#line 344 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 2691 "contacts-store.c"
				goto __catch27_g_error;
			}
		}
		goto __finally27;
		__catch27_g_error:
		{
#line 343 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->e = _data_->_inner_error_;
#line 343 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_inner_error_ = NULL;
#line 346 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp8_ = NULL;
#line 346 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp8_ = _data_->e;
#line 346 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp9_ = NULL;
#line 346 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp9_ = _data_->_tmp8_->message;
#line 346 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			g_warning ("contacts-store.vala:346: Unable to prepare account %s", _data_->_tmp9_);
#line 343 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_g_error_free0 (_data_->e);
#line 2714 "contacts-store.c"
		}
		__finally27:
#line 343 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 343 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->features = (g_free (_data_->features), NULL);
#line 343 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 343 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			g_clear_error (&_data_->_inner_error_);
#line 343 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			return FALSE;
#line 2727 "contacts-store.c"
		}
#line 341 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->features = (g_free (_data_->features), NULL);
#line 2731 "contacts-store.c"
	}
#line 350 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp10_ = NULL;
#line 350 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp10_ = _data_->account;
#line 350 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp11_ = 0U;
#line 350 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp11_ = _data_->addressing;
#line 350 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp12_ = FALSE;
#line 350 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_data_->_tmp12_ = tp_proxy_is_prepared ((TpProxy*) _data_->_tmp10_, _data_->_tmp11_);
#line 350 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	if (_data_->_tmp12_) {
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp13_ = NULL;
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp13_ = _data_->account;
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp14_ = NULL;
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp14_ = tp_proxy_get_object_path ((TpProxy*) _data_->_tmp13_);
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp15_ = NULL;
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp15_ = g_strdup (_data_->_tmp14_);
#line 351 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->k = _data_->_tmp15_;
#line 352 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp17_ = NULL;
#line 352 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp17_ = _data_->account;
#line 352 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp18_ = FALSE;
#line 352 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_data_->_tmp18_ = tp_account_is_enabled (_data_->_tmp17_);
#line 352 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		if (_data_->_tmp18_) {
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp19_ = NULL;
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp19_ = _data_->account;
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp20_ = FALSE;
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp20_ = tp_account_associated_with_uri_scheme (_data_->_tmp19_, "tel");
#line 353 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp16_ = _data_->_tmp20_;
#line 2781 "contacts-store.c"
		} else {
#line 352 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp16_ = FALSE;
#line 2785 "contacts-store.c"
		}
#line 352 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		if (_data_->_tmp16_) {
#line 354 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp21_ = NULL;
#line 354 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp21_ = _data_->self->calling_accounts;
#line 354 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp22_ = NULL;
#line 354 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp22_ = _data_->k;
#line 354 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp23_ = NULL;
#line 354 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp23_ = _data_->account;
#line 354 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			gee_abstract_map_set ((GeeAbstractMap*) _data_->_tmp21_, _data_->_tmp22_, _data_->_tmp23_);
#line 2803 "contacts-store.c"
		} else {
#line 356 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp24_ = NULL;
#line 356 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp24_ = _data_->self->calling_accounts;
#line 356 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp25_ = NULL;
#line 356 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_data_->_tmp25_ = _data_->k;
#line 356 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			gee_abstract_map_unset ((GeeAbstractMap*) _data_->_tmp24_, _data_->_tmp25_, NULL);
#line 2815 "contacts-store.c"
		}
#line 350 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_free0 (_data_->k);
#line 2819 "contacts-store.c"
	}
#line 339 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	if (_data_->_state_ == 0) {
#line 339 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2825 "contacts-store.c"
	} else {
#line 339 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2829 "contacts-store.c"
	}
#line 339 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_object_unref (_data_->_async_result);
#line 339 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return FALSE;
#line 2835 "contacts-store.c"
}


ContactsStore* contacts_store_construct (GType object_type) {
	ContactsStore * self = NULL;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	self = (ContactsStore*) g_object_new (object_type, NULL);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return self;
#line 2845 "contacts-store.c"
}


ContactsStore* contacts_store_new (void) {
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return contacts_store_construct (CONTACTS_TYPE_STORE);
#line 2852 "contacts-store.c"
}


FolksIndividualAggregator* contacts_store_get_aggregator (ContactsStore* self) {
	FolksIndividualAggregator* result;
	FolksIndividualAggregator* _tmp0_ = NULL;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = self->priv->_aggregator;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	result = _tmp0_;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return result;
#line 2867 "contacts-store.c"
}


static void contacts_store_set_aggregator (ContactsStore* self, FolksIndividualAggregator* value) {
	FolksIndividualAggregator* _tmp0_ = NULL;
	FolksIndividualAggregator* _tmp1_ = NULL;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (self != NULL);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = value;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	self->priv->_aggregator = _tmp1_;
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_object_notify ((GObject *) self, "aggregator");
#line 2886 "contacts-store.c"
}


FolksBackendStore* contacts_store_get_backend_store (ContactsStore* self) {
	FolksBackendStore* result;
	FolksBackendStore* _tmp0_ = NULL;
#line 34 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 34 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = self->priv->_backend_store;
#line 34 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	result = _tmp0_;
#line 34 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return result;
#line 2901 "contacts-store.c"
}


static void contacts_store_set_backend_store (ContactsStore* self, FolksBackendStore* value) {
	FolksBackendStore* _tmp0_ = NULL;
	FolksBackendStore* _tmp1_ = NULL;
#line 34 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (self != NULL);
#line 34 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = value;
#line 34 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 34 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (self->priv->_backend_store);
#line 34 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	self->priv->_backend_store = _tmp1_;
#line 34 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_object_notify ((GObject *) self, "backend-store");
#line 2920 "contacts-store.c"
}


gboolean contacts_store_get_can_call (ContactsStore* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
	GeeHashMap* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
#line 42 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp1_ = self->calling_accounts;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp2_ = gee_abstract_map_get_size ((GeeMap*) _tmp1_);
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp3_ = _tmp2_;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	if (_tmp3_ > 0) {
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp0_ = TRUE;
#line 2942 "contacts-store.c"
	} else {
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp0_ = FALSE;
#line 2946 "contacts-store.c"
	}
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	result = _tmp0_;
#line 43 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return result;
#line 2952 "contacts-store.c"
}


gboolean contacts_store_get_is_quiescent (ContactsStore* self) {
	gboolean result;
	FolksIndividualAggregator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 48 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 48 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = self->priv->_aggregator;
#line 48 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp1_ = folks_individual_aggregator_get_is_quiescent (_tmp0_);
#line 48 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp2_ = _tmp1_;
#line 48 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	result = _tmp2_;
#line 48 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return result;
#line 2973 "contacts-store.c"
}


gboolean contacts_store_get_is_prepared (ContactsStore* self) {
	gboolean result;
	FolksIndividualAggregator* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
#line 52 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 52 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = self->priv->_aggregator;
#line 52 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp1_ = folks_individual_aggregator_get_is_prepared (_tmp0_);
#line 52 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp2_ = _tmp1_;
#line 52 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	result = _tmp2_;
#line 52 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return result;
#line 2994 "contacts-store.c"
}


static void ___lambda21_ (ContactsStore* self) {
#line 149 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_emit_by_name (self, "eds-persona-store-changed");
#line 3001 "contacts-store.c"
}


static void ____lambda21__folks_backend_persona_store_added (FolksBackend* _sender, FolksPersonaStore* store, gpointer self) {
#line 148 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	___lambda21_ ((ContactsStore*) self);
#line 3008 "contacts-store.c"
}


static void ___lambda22_ (ContactsStore* self) {
#line 152 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_emit_by_name (self, "eds-persona-store-changed");
#line 3015 "contacts-store.c"
}


static void ____lambda22__folks_backend_persona_store_removed (FolksBackend* _sender, FolksPersonaStore* store, gpointer self) {
#line 151 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	___lambda22_ ((ContactsStore*) self);
#line 3022 "contacts-store.c"
}


static void _contacts_store___lambda20_ (ContactsStore* self, FolksBackend* backend) {
	FolksBackend* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 146 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (backend != NULL);
#line 147 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = backend;
#line 147 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp1_ = folks_backend_get_name (_tmp0_);
#line 147 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp2_ = _tmp1_;
#line 147 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	if (g_strcmp0 (_tmp2_, "eds") == 0) {
#line 3040 "contacts-store.c"
		FolksBackend* _tmp3_ = NULL;
		FolksBackend* _tmp4_ = NULL;
#line 148 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp3_ = backend;
#line 148 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_signal_connect_object (_tmp3_, "persona-store-added", (GCallback) ____lambda21__folks_backend_persona_store_added, self, 0);
#line 151 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp4_ = backend;
#line 151 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_signal_connect_object (_tmp4_, "persona-store-removed", (GCallback) ____lambda22__folks_backend_persona_store_removed, self, 0);
#line 3051 "contacts-store.c"
	}
}


static void __contacts_store___lambda20__folks_backend_store_backend_available (FolksBackendStore* _sender, FolksBackend* backend, gpointer self) {
#line 146 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_contacts_store___lambda20_ ((ContactsStore*) self, backend);
#line 3059 "contacts-store.c"
}


static gboolean __lambda24_ (ContactsStore* self) {
	gboolean result = FALSE;
#line 161 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_emit_by_name (self, "quiescent");
#line 162 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	result = FALSE;
#line 162 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return result;
#line 3071 "contacts-store.c"
}


static gboolean ___lambda24__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda24_ ((ContactsStore*) self);
#line 160 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return result;
#line 3080 "contacts-store.c"
}


static void _contacts_store___lambda23_ (ContactsStore* self, GObject* obj, GParamSpec* pspec) {
#line 158 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (obj != NULL);
#line 158 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (pspec != NULL);
#line 160 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda24__gsource_func, g_object_ref (self), g_object_unref);
#line 3091 "contacts-store.c"
}


static void __contacts_store___lambda23__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 158 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_contacts_store___lambda23_ ((ContactsStore*) self, _sender, pspec);
#line 3098 "contacts-store.c"
}


static gboolean __lambda26_ (ContactsStore* self) {
	gboolean result = FALSE;
#line 168 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_emit_by_name (self, "prepared");
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	result = FALSE;
#line 169 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return result;
#line 3110 "contacts-store.c"
}


static gboolean ___lambda26__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda26_ ((ContactsStore*) self);
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return result;
#line 3119 "contacts-store.c"
}


static void _contacts_store___lambda25_ (ContactsStore* self, GObject* obj, GParamSpec* pspec) {
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (obj != NULL);
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (pspec != NULL);
#line 167 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, ___lambda26__gsource_func, g_object_ref (self), g_object_unref);
#line 3130 "contacts-store.c"
}


static void __contacts_store___lambda25__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_contacts_store___lambda25_ ((ContactsStore*) self, _sender, pspec);
#line 3137 "contacts-store.c"
}


static void _contacts_store___lambda27_ (ContactsStore* self, GeeMultiMap* changes) {
	GeeHashMap* replaced_individuals = NULL;
	GeeHashMap* _tmp0_ = NULL;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_return_if_fail (changes != NULL);
#line 177 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = gee_hash_map_new (FOLKS_TYPE_INDIVIDUAL, (GBoxedCopyFunc) g_object_ref, g_object_unref, FOLKS_TYPE_INDIVIDUAL, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 177 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	replaced_individuals = _tmp0_;
#line 3150 "contacts-store.c"
	{
		GeeIterator* _old_individual_it = NULL;
		GeeMultiMap* _tmp1_ = NULL;
		GeeSet* _tmp2_ = NULL;
		GeeSet* _tmp3_ = NULL;
		GeeIterator* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp1_ = changes;
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp2_ = gee_multi_map_get_keys (_tmp1_);
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp3_ = _tmp2_;
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp4_ = gee_iterable_iterator ((GeeIterable*) _tmp3_);
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp5_ = _tmp4_;
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_object_unref0 (_tmp3_);
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_old_individual_it = _tmp5_;
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		while (TRUE) {
#line 3174 "contacts-store.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* old_individual = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp6_ = _old_individual_it;
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			if (!_tmp7_) {
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				break;
#line 3189 "contacts-store.c"
			}
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp8_ = _old_individual_it;
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			old_individual = (FolksIndividual*) _tmp9_;
#line 181 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp10_ = old_individual;
#line 181 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			if (_tmp10_ == NULL) {
#line 182 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_g_object_unref0 (old_individual);
#line 182 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				continue;
#line 3205 "contacts-store.c"
			}
			{
				GeeIterator* _new_individual_it = NULL;
				GeeMultiMap* _tmp11_ = NULL;
				FolksIndividual* _tmp12_ = NULL;
				GeeCollection* _tmp13_ = NULL;
				GeeCollection* _tmp14_ = NULL;
				GeeIterator* _tmp15_ = NULL;
				GeeIterator* _tmp16_ = NULL;
#line 183 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp11_ = changes;
#line 183 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp12_ = old_individual;
#line 183 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp13_ = gee_multi_map_get (_tmp11_, _tmp12_);
#line 183 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp14_ = _tmp13_;
#line 183 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp15_ = gee_iterable_iterator ((GeeIterable*) _tmp14_);
#line 183 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp16_ = _tmp15_;
#line 183 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_g_object_unref0 (_tmp14_);
#line 183 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_new_individual_it = _tmp16_;
#line 183 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				while (TRUE) {
#line 3233 "contacts-store.c"
					GeeIterator* _tmp17_ = NULL;
					gboolean _tmp18_ = FALSE;
					FolksIndividual* new_individual = NULL;
					GeeIterator* _tmp19_ = NULL;
					gpointer _tmp20_ = NULL;
					FolksIndividual* _tmp21_ = NULL;
					gboolean _tmp22_ = FALSE;
					GeeHashMap* _tmp23_ = NULL;
					FolksIndividual* _tmp24_ = NULL;
					gboolean _tmp25_ = FALSE;
#line 183 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp17_ = _new_individual_it;
#line 183 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp18_ = gee_iterator_next (_tmp17_);
#line 183 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					if (!_tmp18_) {
#line 183 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						break;
#line 3252 "contacts-store.c"
					}
#line 183 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp19_ = _new_individual_it;
#line 183 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp20_ = gee_iterator_get (_tmp19_);
#line 183 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					new_individual = (FolksIndividual*) _tmp20_;
#line 184 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp21_ = new_individual;
#line 184 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					if (_tmp21_ == NULL) {
#line 185 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_g_object_unref0 (new_individual);
#line 185 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						continue;
#line 3268 "contacts-store.c"
					}
#line 186 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp23_ = replaced_individuals;
#line 186 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp24_ = new_individual;
#line 186 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp25_ = gee_abstract_map_has_key ((GeeAbstractMap*) _tmp23_, _tmp24_);
#line 186 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					if (!_tmp25_) {
#line 186 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp22_ = TRUE;
#line 3280 "contacts-store.c"
					} else {
						FolksIndividual* _tmp26_ = NULL;
						gboolean _tmp27_ = FALSE;
#line 187 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp26_ = old_individual;
#line 187 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp27_ = contacts_store_individual_should_replace_at_join (self, _tmp26_);
#line 187 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp22_ = _tmp27_;
#line 3290 "contacts-store.c"
					}
#line 186 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					if (_tmp22_) {
#line 3294 "contacts-store.c"
						GeeHashMap* _tmp28_ = NULL;
						FolksIndividual* _tmp29_ = NULL;
						FolksIndividual* _tmp30_ = NULL;
#line 188 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp28_ = replaced_individuals;
#line 188 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp29_ = new_individual;
#line 188 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp30_ = old_individual;
#line 188 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						gee_abstract_map_set ((GeeAbstractMap*) _tmp28_, _tmp29_, _tmp30_);
#line 3306 "contacts-store.c"
					}
#line 183 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_g_object_unref0 (new_individual);
#line 3310 "contacts-store.c"
				}
#line 183 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_g_object_unref0 (_new_individual_it);
#line 3314 "contacts-store.c"
			}
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_g_object_unref0 (old_individual);
#line 3318 "contacts-store.c"
		}
#line 180 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_object_unref0 (_old_individual_it);
#line 3322 "contacts-store.c"
	}
	{
		GeeIterator* _old_individual_it = NULL;
		GeeMultiMap* _tmp31_ = NULL;
		GeeSet* _tmp32_ = NULL;
		GeeSet* _tmp33_ = NULL;
		GeeIterator* _tmp34_ = NULL;
		GeeIterator* _tmp35_ = NULL;
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp31_ = changes;
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp32_ = gee_multi_map_get_keys (_tmp31_);
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp33_ = _tmp32_;
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp34_ = gee_iterable_iterator ((GeeIterable*) _tmp33_);
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_tmp35_ = _tmp34_;
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_object_unref0 (_tmp33_);
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_old_individual_it = _tmp35_;
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		while (TRUE) {
#line 3347 "contacts-store.c"
			GeeIterator* _tmp36_ = NULL;
			gboolean _tmp37_ = FALSE;
			FolksIndividual* old_individual = NULL;
			GeeIterator* _tmp38_ = NULL;
			gpointer _tmp39_ = NULL;
			GeeHashSet* replacements = NULL;
			GeeHashSet* _tmp71_ = NULL;
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp36_ = _old_individual_it;
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp37_ = gee_iterator_next (_tmp36_);
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			if (!_tmp37_) {
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				break;
#line 3363 "contacts-store.c"
			}
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp38_ = _old_individual_it;
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp39_ = gee_iterator_get (_tmp38_);
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			old_individual = (FolksIndividual*) _tmp39_;
#line 194 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			replacements = NULL;
#line 3373 "contacts-store.c"
			{
				GeeIterator* _new_individual_it = NULL;
				GeeMultiMap* _tmp40_ = NULL;
				FolksIndividual* _tmp41_ = NULL;
				GeeCollection* _tmp42_ = NULL;
				GeeCollection* _tmp43_ = NULL;
				GeeIterator* _tmp44_ = NULL;
				GeeIterator* _tmp45_ = NULL;
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp40_ = changes;
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp41_ = old_individual;
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp42_ = gee_multi_map_get (_tmp40_, _tmp41_);
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp43_ = _tmp42_;
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp44_ = gee_iterable_iterator ((GeeIterable*) _tmp43_);
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp45_ = _tmp44_;
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_g_object_unref0 (_tmp43_);
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_new_individual_it = _tmp45_;
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				while (TRUE) {
#line 3400 "contacts-store.c"
					GeeIterator* _tmp46_ = NULL;
					gboolean _tmp47_ = FALSE;
					FolksIndividual* new_individual = NULL;
					GeeIterator* _tmp48_ = NULL;
					gpointer _tmp49_ = NULL;
					gboolean _tmp50_ = FALSE;
					gboolean _tmp51_ = FALSE;
					FolksIndividual* _tmp52_ = NULL;
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp46_ = _new_individual_it;
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp47_ = gee_iterator_next (_tmp46_);
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					if (!_tmp47_) {
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						break;
#line 3417 "contacts-store.c"
					}
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp48_ = _new_individual_it;
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp49_ = gee_iterator_get (_tmp48_);
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					new_individual = (FolksIndividual*) _tmp49_;
#line 196 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp52_ = old_individual;
#line 196 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					if (_tmp52_ != NULL) {
#line 3429 "contacts-store.c"
						FolksIndividual* _tmp53_ = NULL;
#line 196 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp53_ = new_individual;
#line 196 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp51_ = _tmp53_ != NULL;
#line 3435 "contacts-store.c"
					} else {
#line 196 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp51_ = FALSE;
#line 3439 "contacts-store.c"
					}
#line 196 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					if (_tmp51_) {
#line 3443 "contacts-store.c"
						GeeHashMap* _tmp54_ = NULL;
						FolksIndividual* _tmp55_ = NULL;
						gpointer _tmp56_ = NULL;
						FolksIndividual* _tmp57_ = NULL;
						FolksIndividual* _tmp58_ = NULL;
#line 197 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp54_ = replaced_individuals;
#line 197 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp55_ = new_individual;
#line 197 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp56_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp54_, _tmp55_);
#line 197 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp57_ = (FolksIndividual*) _tmp56_;
#line 197 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp58_ = old_individual;
#line 197 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp50_ = _tmp57_ == _tmp58_;
#line 197 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_g_object_unref0 (_tmp57_);
#line 3463 "contacts-store.c"
					} else {
#line 196 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp50_ = FALSE;
#line 3467 "contacts-store.c"
					}
#line 196 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					if (_tmp50_) {
#line 3471 "contacts-store.c"
						GeeHashSet* _tmp59_ = NULL;
						GeeHashSet* _tmp61_ = NULL;
						FolksIndividual* _tmp62_ = NULL;
#line 198 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp59_ = replacements;
#line 198 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						if (_tmp59_ == NULL) {
#line 3479 "contacts-store.c"
							GeeHashSet* _tmp60_ = NULL;
#line 199 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp60_ = gee_hash_set_new (FOLKS_TYPE_INDIVIDUAL, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 199 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_g_object_unref0 (replacements);
#line 199 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							replacements = _tmp60_;
#line 3487 "contacts-store.c"
						}
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp61_ = replacements;
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp62_ = new_individual;
#line 200 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						gee_abstract_collection_add ((GeeAbstractCollection*) _tmp61_, _tmp62_);
#line 3495 "contacts-store.c"
					} else {
						FolksIndividual* _tmp63_ = NULL;
#line 201 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp63_ = old_individual;
#line 201 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						if (_tmp63_ != NULL) {
#line 3502 "contacts-store.c"
							ContactsContact* c = NULL;
							FolksIndividual* _tmp64_ = NULL;
							ContactsContact* _tmp65_ = NULL;
							ContactsContact* _tmp66_ = NULL;
#line 203 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp64_ = old_individual;
#line 203 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp65_ = contacts_contact_from_individual (_tmp64_);
#line 203 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							c = _tmp65_;
#line 204 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp66_ = c;
#line 204 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							contacts_store_remove (self, _tmp66_);
#line 201 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_g_object_unref0 (c);
#line 3519 "contacts-store.c"
						} else {
							FolksIndividual* _tmp67_ = NULL;
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp67_ = new_individual;
#line 205 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							if (_tmp67_ != NULL) {
#line 3526 "contacts-store.c"
								FolksIndividual* _tmp68_ = NULL;
								ContactsContact* _tmp69_ = NULL;
								ContactsContact* _tmp70_ = NULL;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								_tmp68_ = new_individual;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								_tmp69_ = contacts_contact_new (self, _tmp68_);
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								_tmp70_ = _tmp69_;
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								contacts_store_add (self, _tmp70_);
#line 207 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
								_g_object_unref0 (_tmp70_);
#line 3540 "contacts-store.c"
							}
						}
					}
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_g_object_unref0 (new_individual);
#line 3546 "contacts-store.c"
				}
#line 195 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_g_object_unref0 (_new_individual_it);
#line 3550 "contacts-store.c"
			}
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_tmp71_ = replacements;
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			if (_tmp71_ != NULL) {
#line 3556 "contacts-store.c"
				FolksIndividual* main_individual = NULL;
				ContactsContact* c = NULL;
				FolksIndividual* _tmp82_ = NULL;
				ContactsContact* _tmp83_ = NULL;
				ContactsContact* _tmp84_ = NULL;
				FolksIndividual* _tmp85_ = NULL;
#line 217 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				main_individual = NULL;
#line 3565 "contacts-store.c"
				{
					GeeIterator* _i_it = NULL;
					GeeHashSet* _tmp72_ = NULL;
					GeeIterator* _tmp73_ = NULL;
#line 218 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp72_ = replacements;
#line 218 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp73_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _tmp72_);
#line 218 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_i_it = _tmp73_;
#line 218 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					while (TRUE) {
#line 3578 "contacts-store.c"
						GeeIterator* _tmp74_ = NULL;
						gboolean _tmp75_ = FALSE;
						FolksIndividual* i = NULL;
						GeeIterator* _tmp76_ = NULL;
						gpointer _tmp77_ = NULL;
						FolksIndividual* _tmp78_ = NULL;
						FolksIndividual* _tmp79_ = NULL;
						FolksIndividual* _tmp80_ = NULL;
						gboolean _tmp81_ = FALSE;
#line 218 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp74_ = _i_it;
#line 218 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp75_ = gee_iterator_next (_tmp74_);
#line 218 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						if (!_tmp75_) {
#line 218 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							break;
#line 3596 "contacts-store.c"
						}
#line 218 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp76_ = _i_it;
#line 218 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp77_ = gee_iterator_get (_tmp76_);
#line 218 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						i = (FolksIndividual*) _tmp77_;
#line 219 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp78_ = i;
#line 219 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp79_ = _g_object_ref0 (_tmp78_);
#line 219 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_g_object_unref0 (main_individual);
#line 219 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						main_individual = _tmp79_;
#line 224 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp80_ = i;
#line 224 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp81_ = contacts_store_individual_can_replace_at_split (self, _tmp80_);
#line 224 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						if (_tmp81_) {
#line 225 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_g_object_unref0 (i);
#line 225 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							break;
#line 3622 "contacts-store.c"
						}
#line 218 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_g_object_unref0 (i);
#line 3626 "contacts-store.c"
					}
#line 218 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_g_object_unref0 (_i_it);
#line 3630 "contacts-store.c"
				}
#line 228 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp82_ = old_individual;
#line 228 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp83_ = contacts_contact_from_individual (_tmp82_);
#line 228 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				c = _tmp83_;
#line 229 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp84_ = c;
#line 229 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_tmp85_ = main_individual;
#line 229 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				contacts_contact_replace_individual (_tmp84_, _tmp85_);
#line 3644 "contacts-store.c"
				{
					GeeIterator* _i_it = NULL;
					GeeHashSet* _tmp86_ = NULL;
					GeeIterator* _tmp87_ = NULL;
#line 230 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp86_ = replacements;
#line 230 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_tmp87_ = gee_abstract_collection_iterator ((GeeAbstractCollection*) _tmp86_);
#line 230 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_i_it = _tmp87_;
#line 230 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					while (TRUE) {
#line 3657 "contacts-store.c"
						GeeIterator* _tmp88_ = NULL;
						gboolean _tmp89_ = FALSE;
						FolksIndividual* i = NULL;
						GeeIterator* _tmp90_ = NULL;
						gpointer _tmp91_ = NULL;
						FolksIndividual* _tmp92_ = NULL;
						FolksIndividual* _tmp93_ = NULL;
#line 230 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp88_ = _i_it;
#line 230 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp89_ = gee_iterator_next (_tmp88_);
#line 230 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						if (!_tmp89_) {
#line 230 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							break;
#line 3673 "contacts-store.c"
						}
#line 230 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp90_ = _i_it;
#line 230 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp91_ = gee_iterator_get (_tmp90_);
#line 230 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						i = (FolksIndividual*) _tmp91_;
#line 231 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp92_ = i;
#line 231 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_tmp93_ = main_individual;
#line 231 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						if (_tmp92_ != _tmp93_) {
#line 3687 "contacts-store.c"
							FolksIndividual* _tmp94_ = NULL;
							ContactsContact* _tmp95_ = NULL;
							ContactsContact* _tmp96_ = NULL;
#line 234 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp94_ = i;
#line 234 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp95_ = contacts_contact_new (self, _tmp94_);
#line 234 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_tmp96_ = _tmp95_;
#line 234 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							contacts_store_add (self, _tmp96_);
#line 234 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
							_g_object_unref0 (_tmp96_);
#line 3701 "contacts-store.c"
						}
#line 230 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
						_g_object_unref0 (i);
#line 3705 "contacts-store.c"
					}
#line 230 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
					_g_object_unref0 (_i_it);
#line 3709 "contacts-store.c"
				}
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_g_object_unref0 (c);
#line 216 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
				_g_object_unref0 (main_individual);
#line 3715 "contacts-store.c"
			}
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_g_object_unref0 (replacements);
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
			_g_object_unref0 (old_individual);
#line 3721 "contacts-store.c"
		}
#line 193 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		_g_object_unref0 (_old_individual_it);
#line 3725 "contacts-store.c"
	}
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (replaced_individuals);
#line 3729 "contacts-store.c"
}


static void __contacts_store___lambda27__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_contacts_store___lambda27_ ((ContactsStore*) self, changes);
#line 3736 "contacts-store.c"
}


static GObject * contacts_store_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	ContactsStore * self;
	GeeArrayList* _tmp0_ = NULL;
	GeeHashMultiMap* _tmp1_ = NULL;
	FolksBackendStore* _tmp2_ = NULL;
	FolksBackendStore* _tmp3_ = NULL;
	FolksBackendStore* _tmp4_ = NULL;
	FolksIndividualAggregator* _tmp5_ = NULL;
	FolksIndividualAggregator* _tmp6_ = NULL;
	FolksIndividualAggregator* _tmp7_ = NULL;
	FolksIndividualAggregator* _tmp8_ = NULL;
	FolksIndividualAggregator* _tmp9_ = NULL;
	FolksIndividualAggregator* _tmp10_ = NULL;
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	parent_class = G_OBJECT_CLASS (contacts_store_parent_class);
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, CONTACTS_TYPE_STORE, ContactsStore);
#line 140 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp0_ = gee_array_list_new (CONTACTS_TYPE_CONTACT, (GBoxedCopyFunc) g_object_ref, g_object_unref, NULL, NULL, NULL);
#line 140 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (self->priv->contacts);
#line 140 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	self->priv->contacts = _tmp0_;
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp1_ = gee_hash_multi_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (self->dont_suggest_link);
#line 142 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	self->dont_suggest_link = _tmp1_;
#line 143 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	contacts_store_read_dont_suggest_db (self);
#line 145 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp2_ = folks_backend_store_dup ();
#line 145 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp3_ = _tmp2_;
#line 145 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	contacts_store_set_backend_store (self, _tmp3_);
#line 145 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (_tmp3_);
#line 146 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp4_ = self->priv->_backend_store;
#line 146 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_connect_object (_tmp4_, "backend-available", (GCallback) __contacts_store___lambda20__folks_backend_store_backend_available, self, 0);
#line 157 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp5_ = folks_individual_aggregator_dup ();
#line 157 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp6_ = _tmp5_;
#line 157 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	contacts_store_set_aggregator (self, _tmp6_);
#line 157 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (_tmp6_);
#line 158 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp7_ = self->priv->_aggregator;
#line 158 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_connect_object ((GObject*) _tmp7_, "notify::is-quiescent", (GCallback) __contacts_store___lambda23__g_object_notify, self, 0);
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp8_ = self->priv->_aggregator;
#line 166 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_connect_object ((GObject*) _tmp8_, "notify::is-prepared", (GCallback) __contacts_store___lambda25__g_object_notify, self, 0);
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp9_ = self->priv->_aggregator;
#line 173 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_connect_object (_tmp9_, "individuals-changed-detailed", (GCallback) __contacts_store___lambda27__folks_individual_aggregator_individuals_changed_detailed, self, 0);
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_tmp10_ = self->priv->_aggregator;
#line 240 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	folks_individual_aggregator_prepare (_tmp10_, NULL, NULL);
#line 242 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	contacts_store_check_call_capabilities (self, NULL, NULL);
#line 139 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	return obj;
#line 3815 "contacts-store.c"
}


static void contacts_store_class_init (ContactsStoreClass * klass) {
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	contacts_store_parent_class = g_type_class_peek_parent (klass);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_type_class_add_private (klass, sizeof (ContactsStorePrivate));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_contacts_store_get_property;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_contacts_store_set_property;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	G_OBJECT_CLASS (klass)->constructor = contacts_store_constructor;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	G_OBJECT_CLASS (klass)->finalize = contacts_store_finalize;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), CONTACTS_STORE_AGGREGATOR, g_param_spec_object ("aggregator", "aggregator", "aggregator", FOLKS_TYPE_INDIVIDUAL_AGGREGATOR, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), CONTACTS_STORE_BACKEND_STORE, g_param_spec_object ("backend-store", "backend-store", "backend-store", FOLKS_TYPE_BACKEND_STORE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), CONTACTS_STORE_CAN_CALL, g_param_spec_boolean ("can-call", "can-call", "can-call", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), CONTACTS_STORE_IS_QUIESCENT, g_param_spec_boolean ("is-quiescent", "is-quiescent", "is-quiescent", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), CONTACTS_STORE_IS_PREPARED, g_param_spec_boolean ("is-prepared", "is-prepared", "is-prepared", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_new ("changed", CONTACTS_TYPE_STORE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, CONTACTS_TYPE_CONTACT);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_new ("added", CONTACTS_TYPE_STORE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, CONTACTS_TYPE_CONTACT);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_new ("removed", CONTACTS_TYPE_STORE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, CONTACTS_TYPE_CONTACT);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_new ("quiescent", CONTACTS_TYPE_STORE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_new ("prepared", CONTACTS_TYPE_STORE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	g_signal_new ("eds_persona_store_changed", CONTACTS_TYPE_STORE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 3854 "contacts-store.c"
}


static void contacts_store_instance_init (ContactsStore * self) {
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	self->priv = CONTACTS_STORE_GET_PRIVATE (self);
#line 3861 "contacts-store.c"
}


static void contacts_store_finalize (GObject* obj) {
	ContactsStore * self;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, CONTACTS_TYPE_STORE, ContactsStore);
#line 33 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (self->priv->_aggregator);
#line 34 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (self->priv->_backend_store);
#line 35 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (self->priv->contacts);
#line 37 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (self->calling_accounts);
#line 39 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	_g_object_unref0 (self->dont_suggest_link);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	G_OBJECT_CLASS (contacts_store_parent_class)->finalize (obj);
#line 3881 "contacts-store.c"
}


GType contacts_store_get_type (void) {
	static volatile gsize contacts_store_type_id__volatile = 0;
	if (g_once_init_enter (&contacts_store_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ContactsStoreClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) contacts_store_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ContactsStore), 0, (GInstanceInitFunc) contacts_store_instance_init, NULL };
		GType contacts_store_type_id;
		contacts_store_type_id = g_type_register_static (G_TYPE_OBJECT, "ContactsStore", &g_define_type_info, 0);
		g_once_init_leave (&contacts_store_type_id__volatile, contacts_store_type_id);
	}
	return contacts_store_type_id__volatile;
}


static void _vala_contacts_store_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ContactsStore * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, CONTACTS_TYPE_STORE, ContactsStore);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	switch (property_id) {
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		case CONTACTS_STORE_AGGREGATOR:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_value_set_object (value, contacts_store_get_aggregator (self));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		break;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		case CONTACTS_STORE_BACKEND_STORE:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_value_set_object (value, contacts_store_get_backend_store (self));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		break;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		case CONTACTS_STORE_CAN_CALL:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_value_set_boolean (value, contacts_store_get_can_call (self));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		break;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		case CONTACTS_STORE_IS_QUIESCENT:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_value_set_boolean (value, contacts_store_get_is_quiescent (self));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		break;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		case CONTACTS_STORE_IS_PREPARED:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		g_value_set_boolean (value, contacts_store_get_is_prepared (self));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		break;
#line 3932 "contacts-store.c"
		default:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		break;
#line 3938 "contacts-store.c"
	}
}


static void _vala_contacts_store_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ContactsStore * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, CONTACTS_TYPE_STORE, ContactsStore);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
	switch (property_id) {
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		case CONTACTS_STORE_AGGREGATOR:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		contacts_store_set_aggregator (self, g_value_get_object (value));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		break;
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		case CONTACTS_STORE_BACKEND_STORE:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		contacts_store_set_backend_store (self, g_value_get_object (value));
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		break;
#line 3960 "contacts-store.c"
		default:
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 24 "/home/mcatanzaro/src/jhbuild/checkout/gnome-contacts/src/contacts-store.vala"
		break;
#line 3966 "contacts-store.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



